@@ -1,9 +1,10 @@
 /*
- *  Copyright 1999-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -282,7 +283,7 @@ public class JkMain implements MBeanRegistration
                 try {
                     wEnv.getHandler(i).destroy();
                 } catch( IOException ex) {
-                    log.error("Error stoping " + wEnv.getHandler(i).getName(), ex);
+                    log.error("Error stopping " + wEnv.getHandler(i).getName(), ex);
                 }
             }
         }
