@@ -1,9 +1,10 @@
 /*
- *  Copyright 1999-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -19,7 +20,7 @@ import java.io.Serializable;
 
 /**
  * @author Peter Rossbach
- * @version $Revision:$ $Date:$
+ * @version $Revision: 500550 $ $Date: 2007-01-27 08:41:36 -0700 (Sat, 27 Jan 2007) $
  * @see org.apache.jk.status.JkStatusParser
  */
 /**
@@ -28,13 +29,16 @@ import java.io.Serializable;
  */
 public class JkBalancerMember implements Serializable {
     
-    int id;
+    int id = -1;
 
     String name;
 
-    /* possible with > 1.2.16 */
+    /* possible with >= 1.2.16 */
     String jvm_route;
 
+    /* possible with >= 1.2.20 */
+    String route;
+
     String type;
 
     String host;
@@ -81,9 +85,19 @@ public class JkBalancerMember implements Serializable {
     /* possible with > 1.2.16 */
     int distance = -1;
 
+    /* possible with > 1.2.20 */
+    int time_to_recover = -1 ;
+    
+    /* possible with > 1.2.21 */
+    int time_to_recover_max = -1 ;
+    
+    /* possible with > 1.2.21 */
+    int time_to_recover_min = -1 ;
+    
     /**
      * @return Returns the jvm_route.
-     * @since mod_jk 1.2.19
+     * @since mod_jk 1.2.16
+     * @deprecated
      */
     public String getJvm_route() {
         return jvm_route;
@@ -91,12 +105,29 @@ public class JkBalancerMember implements Serializable {
 
     /**
      * @param jvm_route The jvm_route to set.
-     * @since mod_jk 1.2.19
+     * @since mod_jk 1.2.16
+     * @deprecated
      */
     public void setJvm_route(String jvm_route) {
         this.jvm_route = jvm_route;
     }
 
+    /**
+     * @return the route
+    * @since mod_jk 1.2.20
+     */
+    public String getRoute() {
+        return route;
+    }
+
+    /**
+     * @param route the route to set
+    * @since mod_jk 1.2.20
+     */
+    public void setRoute(String route) {
+        this.route = route;
+    }
+
     /**
      * @return Returns the address.
      */
@@ -132,7 +163,7 @@ public class JkBalancerMember implements Serializable {
      * @return Returns the maxbusy.
      * @since mod_jk 1.2.18
      */
-    public int getMaxbusy() {
+    public int getMax_busy() {
         return maxbusy;
     }
 
@@ -140,7 +171,7 @@ public class JkBalancerMember implements Serializable {
      * @param maxbusy The maxbusy to set.
      * @since mod_jk 1.2.18
      */
-    public void setMaxbusy(int maxbusy) {
+    public void setMax_busy(int maxbusy) {
         this.maxbusy = maxbusy;
     }
 
@@ -163,7 +194,7 @@ public class JkBalancerMember implements Serializable {
      * @return Returns the clienterrors.
      * @since mod_jk 1.2.19
      */
-    public long getClienterrors() {
+    public long getClient_errors() {
         return clienterrors;
     }
 
@@ -171,7 +202,7 @@ public class JkBalancerMember implements Serializable {
      * @param clienterrors The clienterrors to set.
      * @since mod_jk 1.2.19
      */
-    public void setClienterrors(long clienterrors) {
+    public void setClient_errors(long clienterrors) {
         this.clienterrors = clienterrors;
     }
 
@@ -434,5 +465,52 @@ public class JkBalancerMember implements Serializable {
         this.distance = distance;
     }
 
+    /**
+     * @return the time_to_recover
+     * @since mod_jk 1.2.20
+     */
+    public int getTime_to_recover() {
+        return time_to_recover;
+    }
+
+    /**
+     * @param time_to_recover the time_to_recover to set
+     * @since mod_jk 1.2.20
+     */
+    public void setTime_to_recover(int time_to_recover) {
+        this.time_to_recover = time_to_recover;
+    }
+
+    /**
+     * @return the time_to_recover_min
+     * @since mod_jk 1.2.21
+     */
+    public int getTime_to_recover_min() {
+        return time_to_recover_min;
+    }
+
+    /**
+     * @param time_to_recover_min the time_to_recover_min to set
+     * @since mod_jk 1.2.21
+     */
+    public void setTime_to_recover_min(int time_to_recover_min) {
+        this.time_to_recover_min = time_to_recover_min;
+    }
+
+    /**
+     * @return the time_to_recover_max
+     * @since mod_jk 1.2.21
+     */
+    public int getTime_to_recover_max() {
+        return time_to_recover_max;
+    }
+
+    /**
+     * @param time_to_recover_max the time_to_recover_max to set
+     * @since mod_jk 1.2.21
+     */
+    public void setTime_to_recover_max(int time_to_recover_max) {
+        this.time_to_recover_max = time_to_recover_max;
+    }
 
 }
