@@ -20,7 +20,7 @@
  *              This worker is deprecated                                  *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Based on:    jserv_ajpv12.c from Jserv                                  *
- * Version:     $Revision: 559467 $                                          *
+ * Version:     $Revision: 609760 $                                          *
  ***************************************************************************/
 
 #include "jk_ajp12_worker.h"
@@ -84,6 +84,19 @@ static int ajpv12_handle_response(ajp12_endpoint_t * p,
 static int ajpv12_handle_request(ajp12_endpoint_t * p,
                                  jk_ws_service_t *s, jk_logger_t *l);
 
+/*
+ * Return values of service() method for ajp12 worker:
+ * return value  is_error              reason
+ * JK_FALSE      JK_HTTP_SERVER_ERROR  Invalid parameters (null values)
+ *                                     Error during connect to the backend
+ *                                     ajpv12_handle_request() returns false:
+ *           Any error during reading a request body from the client or
+ *           sending the request to the backend
+ * JK_FALSE      JK_HTTP_OK            ajpv12_handle_response() returns false:
+ *           Any error during reading parts of response from backend or
+ *           sending to client
+ * JK_TRUE       JK_HTTP_OK            All other cases
+ */
 static int JK_METHOD service(jk_endpoint_t *e,
                              jk_ws_service_t *s,
                              jk_logger_t *l, int *is_error)
@@ -114,7 +127,7 @@ static int JK_METHOD service(jk_endpoint_t *e,
          attempt++) {
         p->sd =
             jk_open_socket(&p->worker->worker_inet_addr,
-                           JK_FALSE, -1, 0, l);
+                           JK_FALSE, 0, 0, l);
 
         jk_log(l, JK_LOG_DEBUG, "In jk_endpoint_t::service, sd = %d",
                p->sd);
@@ -147,7 +160,7 @@ static int JK_METHOD done(jk_endpoint_t **e, jk_logger_t *l)
     if (e && *e && (*e)->endpoint_private) {
         ajp12_endpoint_t *p = (*e)->endpoint_private;
         if (IS_VALID_SOCKET(p->sd)) {
-            jk_shutdown_socket(p->sd);
+            jk_shutdown_socket(p->sd, l);
         }
         free(p);
         *e = NULL;
@@ -179,7 +192,7 @@ static int JK_METHOD validate(jk_worker_t *pThis,
                p->name, host, port);
 
         if (port > 1024 && host) {
-            if (jk_resolve(host, port, &p->worker_inet_addr)) {
+            if (jk_resolve(host, port, &p->worker_inet_addr, l)) {
                 return JK_TRUE;
             }
             jk_log(l, JK_LOG_ERROR,
@@ -267,7 +280,6 @@ int JK_METHOD ajp12_worker_factory(jk_worker_t **w,
                 private_data->worker.get_endpoint = get_endpoint;
                 private_data->worker.destroy = destroy;
                 private_data->worker.maintain = NULL;
-                private_data->worker.retries = JK_RETRIES;
 
                 *w = &private_data->worker;
                 return JK_AJP12_WORKER_TYPE;
@@ -527,7 +539,7 @@ static int ajpv12_handle_response(ajp12_endpoint_t * p,
         char *line = NULL;
         char *name = NULL;
         char *value = NULL;
-#ifdef _REENTRANT
+#ifdef _MT_CODE_PTHREAD
         char *lasts;
 #endif
 
@@ -575,7 +587,7 @@ static int ajpv12_handle_response(ajp12_endpoint_t * p,
         jk_log(l, JK_LOG_DEBUG, "ajpv12_handle_response, read %s=%s", name,
                value);
         if (0 == strcmp("Status", name)) {
-#ifdef _REENTRANT
+#ifdef _MT_CODE_PTHREAD
             char *numeric = strtok_r(value, " \t", &lasts);
 #else
             char *numeric = strtok(value, " \t");
@@ -587,7 +599,7 @@ static int ajpv12_handle_response(ajp12_endpoint_t * p,
                        "ajpv12_handle_response, invalid status code");
                 return JK_FALSE;
             }
-#ifdef _REENTRANT
+#ifdef _MT_CODE_PTHREAD
             reason = jk_pool_strdup(s->pool, strtok_r(NULL, " \t", &lasts));
 #else
             reason = jk_pool_strdup(s->pool, strtok(NULL, " \t"));
