@@ -1,9 +1,10 @@
 /*
- *  Copyright 1999-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -18,7 +19,7 @@
  * Description: common stuff for bi-directional protocol ajp13/ajp14.      *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Henri Gomez <hgomez@apache.org>                            *
- * Version:     $Revision: 439553 $                                          *
+ * Version:     $Revision: 611672 $                                          *
  ***************************************************************************/
 
 #ifndef JK_AJP_COMMON_H
@@ -26,6 +27,7 @@
 
 #include "jk_service.h"
 #include "jk_msg_buff.h"
+#include "jk_shm.h"
 #include "jk_mt.h"
 
 #ifdef __cplusplus
@@ -33,6 +35,22 @@ extern "C"
 {
 #endif                          /* __cplusplus */
 
+#define JK_AJP_STATE_IDLE               (0)
+#define JK_AJP_STATE_OK                 (1)
+#define JK_AJP_STATE_ERROR              (2)
+#define JK_AJP_STATE_PROBE              (3)
+#define JK_AJP_STATE_DEF                (JK_AJP_STATE_IDLE)
+#define JK_AJP_STATE_TEXT_IDLE          ("OK/IDLE")
+#define JK_AJP_STATE_TEXT_OK            ("OK")
+#define JK_AJP_STATE_TEXT_ERROR         ("ERR")
+#define JK_AJP_STATE_TEXT_PROBE         ("ERR/PRB")
+#define JK_AJP_STATE_TEXT_MAX           (JK_AJP_STATE_PROBE)
+#define JK_AJP_STATE_TEXT_DEF           (JK_AJP_STATE_TEXT_IDLE)
+
+/* We accept doing global maintenance if we are */
+/* JK_AJP_MAINTAIN_TOLERANCE seconds early. */
+#define JK_AJP_MAINTAIN_TOLERANCE (2)
+
 /*
  * Conditional request attributes
  *
@@ -42,7 +60,7 @@ extern "C"
 #define SC_A_REMOTE_USER        (unsigned char)3
 #define SC_A_AUTH_TYPE          (unsigned char)4
 #define SC_A_QUERY_STRING       (unsigned char)5
-#define SC_A_JVM_ROUTE          (unsigned char)6
+#define SC_A_ROUTE              (unsigned char)6
 #define SC_A_SSL_CERT           (unsigned char)7
 #define SC_A_SSL_CIPHER         (unsigned char)8
 #define SC_A_SSL_SESSION        (unsigned char)9
@@ -194,13 +212,15 @@ extern "C"
 #define AJP_DEF_REPLY_TIMEOUT     (0)   /* NO REPLY TIMEOUT                        */
 #define AJP_DEF_PREPOST_TIMEOUT   (0)   /* NO PREPOST TIMEOUT => NO CPING/CPONG    */
 #define AJP_DEF_RECOVERY_OPTS     (0)   /* NO RECOVERY / NO    */
-#define AJP_DEF_SOCKET_TIMEOUT    (-1)  /* No timeout */
+#define AJP_DEF_SOCKET_TIMEOUT    (0)  /* No timeout */
 
-#define RECOVER_ABORT_IF_TCGETREQUEST    0x0001 /* DONT RECOVER IF TOMCAT FAIL AFTER RECEIVING REQUEST */
-#define RECOVER_ABORT_IF_TCSENDHEADER    0x0002 /* DONT RECOVER IF TOMCAT FAIL AFTER SENDING HEADERS */
+#define RECOVER_ABORT_IF_TCGETREQUEST    0x0001 /* DON'T RECOVER IF TOMCAT FAILS AFTER RECEIVING REQUEST */
+#define RECOVER_ABORT_IF_TCSENDHEADER    0x0002 /* DON'T RECOVER IF TOMCAT FAILS AFTER SENDING HEADERS */
 #define RECOVER_ABORT_IF_CLIENTERROR     0x0004 /* CLOSE THE SOCKET IN CASE OF CLIENT ERROR */
+#define RECOVER_ALWAYS_HTTP_HEAD         0x0008 /* RECOVER HTTP HEAD REQUESTS, EVEN IF ABORT OPTIONS ARE SET */
+#define RECOVER_ALWAYS_HTTP_GET          0x0010 /* RECOVER HTTP GET REQUESTS, EVEN IF ABORT OPTIONS ARE SET */
 
-
+#define JK_MAX_HTTP_STATUS_FAILS   32   /* Should be enough for most 400 and 500 statuses */
 
 struct jk_res_data
 {
@@ -229,11 +249,26 @@ typedef struct ajp_worker ajp_worker_t;
 
 struct ajp_worker
 {
+    jk_worker_t worker;
+    /* Shared memory worker data */
+    jk_shm_ajp_worker_t *s;
+
+    char         name[JK_SHM_STR_SIZ+1];
+    /* Sequence counter starting at 0 and increasing
+     * every time we change the config
+     */
+    volatile unsigned int sequence;
+
+    jk_pool_t p;
+    jk_pool_atom_t buf[TINY_POOL_SIZE];
+
+    JK_CRIT_SEC cs;
+
     struct sockaddr_in worker_inet_addr;    /* Contains host and port */
     unsigned connect_retry_attempts;
-    const char *name;
     const char *host;
     int port;
+    int maintain_time;
     /*
      * Open connections cache...
      *
@@ -241,7 +276,6 @@ struct ajp_worker
      * 2. Cache size.
      * 3. An array of "open" endpoints.
      */
-    JK_CRIT_SEC cs;
     unsigned int ep_cache_sz;
     unsigned int ep_mincache_sz;
     unsigned int ep_maxcache_sz;
@@ -254,8 +288,6 @@ struct ajp_worker
     /* Weak secret similar with ajp12, used in ajp13 */
     const char *secret;
 
-    jk_worker_t worker;
-
     /*
      * Post physical connect handler.
      * AJP14 will set here its login handler
@@ -281,11 +313,23 @@ struct ajp_worker
     int prepost_timeout;   /* before sending a request cping/cpong timeout delay in ms (0 means disabled) */
 
     /*
-     * Recovery option
+     * Recovery options
      */
-    unsigned int recovery_opts; /* Set the recovery option */
+    unsigned int recovery_opts;
     
+    /*
+     * Public property to enable the number of retry attempts
+     * on this worker.
+     */
+    int retries;
+
     unsigned int max_packet_size;  /*  Maximum AJP Packet size */
+    
+    /* 
+     * HTTP status that will cause failover (0 means disabled)
+     */
+     unsigned int http_status_fail_num;
+     int http_status_fail[JK_MAX_HTTP_STATUS_FAILS];
 };
 
 
@@ -306,7 +350,7 @@ struct ajp_endpoint
 
     jk_endpoint_t endpoint;
 
-    unsigned int left_bytes_to_send;
+    jk_uint64_t left_bytes_to_send;
 
     /* time of the last request
        handled by this endpoint */
@@ -333,6 +377,10 @@ struct ajp_operation
  */
 
 
+const char *jk_ajp_get_state(ajp_worker_t *aw, jk_logger_t *l);
+
+int jk_ajp_get_state_code(const char *v);
+
 int ajp_validate(jk_worker_t *pThis,
                  jk_map_t *props,
                  jk_worker_env_t *we, jk_logger_t *l, int proto);
@@ -341,6 +389,9 @@ int ajp_init(jk_worker_t *pThis,
              jk_map_t *props,
              jk_worker_env_t *we, jk_logger_t *l, int proto);
 
+int JK_METHOD ajp_worker_factory(jk_worker_t **w,
+                                 const char *name, jk_logger_t *l);
+
 int ajp_destroy(jk_worker_t **pThis, jk_logger_t *l, int proto);
 
 int JK_METHOD ajp_done(jk_endpoint_t **e, jk_logger_t *l);
@@ -352,6 +403,10 @@ int ajp_connect_to_endpoint(ajp_endpoint_t * ae, jk_logger_t *l);
 
 void ajp_close_endpoint(ajp_endpoint_t * ae, jk_logger_t *l);
 
+void jk_ajp_pull(ajp_worker_t * aw, jk_logger_t *l);
+
+void jk_ajp_push(ajp_worker_t * aw, jk_logger_t *l);
+
 int ajp_connection_tcp_send_message(ajp_endpoint_t * ae,
                                     jk_msg_buf_t *msg, jk_logger_t *l);
 
