@@ -19,7 +19,7 @@
  * Description: In process JNI worker                                      *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Based on:                                                               *
- * Version:     $Revision: 559197 $                                           *
+ * Version:     $Revision: 609760 $                                           *
  ***************************************************************************/
 
 #if !defined(WIN32) && !defined(NETWARE) && !defined(AS400)
@@ -248,6 +248,14 @@ static void print_signals(sigset_t * sset)
 }
 #endif
 
+/*
+ * Return values of service() method for jni worker:
+ * return value  is_error              reason
+ * JK_FALSE      JK_HTTP_SERVER_ERROR  Invalid parameters (null values)
+ *                                     Error during attach to the JNI backend
+ *                                     Error during JNI call
+ * JK_TRUE       JK_HTTP_OK            All other cases
+ */
 static int JK_METHOD service(jk_endpoint_t *e,
                              jk_ws_service_t *s,
                              jk_logger_t *l, int *is_error)
@@ -702,7 +710,6 @@ int JK_METHOD jni_worker_factory(jk_worker_t **w,
     private_data->worker.init = init;
     private_data->worker.get_endpoint = get_endpoint;
     private_data->worker.destroy = destroy;
-    private_data->worker.retries = JK_RETRIES;
 
     *w = &private_data->worker;
     the_singleton_jni_worker = &private_data->worker;
