@@ -1,9 +1,10 @@
 /*
- *  Copyright 1999-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -18,7 +19,7 @@
  * Description: load balance worker header file                            *
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 439810 $                                           *
+ * Version:     $Revision: 613544 $                                           *
  ***************************************************************************/
 
 #ifndef JK_LB_WORKER_H
@@ -36,38 +37,68 @@ extern "C"
 
 #define JK_LB_WORKER_NAME     ("lb")
 #define JK_LB_WORKER_TYPE     (5)
+#define JK_LB_SUB_WORKER_TYPE (7)
 #define JK_LB_DEF_DOMAIN_NAME ("unknown")
 
-#define JK_LB_METHOD_REQUESTS          (1)
-#define JK_LB_METHOD_TRAFFIC           (2)
-#define JK_LB_METHOD_BUSYNESS          (3)
+#define JK_LB_METHOD_REQUESTS          (0)
+#define JK_LB_METHOD_TRAFFIC           (1)
+#define JK_LB_METHOD_BUSYNESS          (2)
+#define JK_LB_METHOD_SESSIONS          (3)
 #define JK_LB_METHOD_DEF               (JK_LB_METHOD_REQUESTS)
+#define JK_LB_METHOD_MAX               (JK_LB_METHOD_SESSIONS)
 #define JK_LB_METHOD_TEXT_REQUESTS     ("Request")
 #define JK_LB_METHOD_TEXT_TRAFFIC      ("Traffic")
 #define JK_LB_METHOD_TEXT_BUSYNESS     ("Busyness")
+#define JK_LB_METHOD_TEXT_SESSIONS     ("Sessions")
 #define JK_LB_METHOD_TEXT_DEF          (JK_LB_METHOD_TEXT_REQUESTS)
-#define JK_LB_LOCK_OPTIMISTIC          (1)
-#define JK_LB_LOCK_PESSIMISTIC         (2)
+#define JK_LB_LOCK_OPTIMISTIC          (0)
+#define JK_LB_LOCK_PESSIMISTIC         (1)
 #define JK_LB_LOCK_DEF                 (JK_LB_LOCK_OPTIMISTIC)
+#define JK_LB_LOCK_MAX                 (JK_LB_LOCK_PESSIMISTIC)
 #define JK_LB_LOCK_TEXT_OPTIMISTIC     ("Optimistic")
 #define JK_LB_LOCK_TEXT_PESSIMISTIC    ("Pessimistic")
 #define JK_LB_LOCK_TEXT_DEF            (JK_LB_LOCK_TEXT_OPTIMISTIC)
-#define JK_LB_STATE_NA                 (1)
-#define JK_LB_STATE_OK                 (2)
-#define JK_LB_STATE_RECOVER            (3)
+/*
+ * The following definitions for state and activation
+ * need to be kept in sync with the two macros 
+ * JK_WORKER_USABLE() and JK_WORKER_USABLE_STICKY() in jk_lb_worker.c.
+ * Since we use ordered comparisons there instead of multiple
+ * equal/unequal compares, order of the values is critical here.
+ */
+#define JK_LB_STATE_IDLE               (0)
+#define JK_LB_STATE_OK                 (1)
+#define JK_LB_STATE_RECOVER            (2)
+#define JK_LB_STATE_FORCE              (3)
 #define JK_LB_STATE_BUSY               (4)
 #define JK_LB_STATE_ERROR              (5)
-#define JK_LB_STATE_TEXT_NA            ("N/A")
+#define JK_LB_STATE_PROBE              (6)
+#define JK_LB_STATE_DEF                (JK_LB_STATE_IDLE)
+#define JK_LB_STATE_TEXT_IDLE          ("OK/IDLE")
 #define JK_LB_STATE_TEXT_OK            ("OK")
-#define JK_LB_STATE_TEXT_RECOVER       ("REC")
-#define JK_LB_STATE_TEXT_BUSY          ("BSY")
+#define JK_LB_STATE_TEXT_RECOVER       ("ERR/REC")
+#define JK_LB_STATE_TEXT_BUSY          ("OK/BUSY")
+#define JK_LB_STATE_TEXT_FORCE         ("ERR/FRC")
 #define JK_LB_STATE_TEXT_ERROR         ("ERR")
-#define JK_LB_ACTIVATION_ACTIVE        (1)
-#define JK_LB_ACTIVATION_DISABLED      (2)
-#define JK_LB_ACTIVATION_STOPPED       (3)
+#define JK_LB_STATE_TEXT_PROBE         ("ERR/PRB")
+#define JK_LB_STATE_TEXT_MAX           (JK_LB_STATE_PROBE)
+#define JK_LB_STATE_TEXT_DEF           (JK_LB_STATE_TEXT_IDLE)
+/* All JK_LB_ACTIVATION_* values must be single digit. */
+/* Otherwise the string encoding of the activation array */
+/* fails e.g. in the isapi redirector. */
+/* JK_LB_ACTIVATION_UNSET is not allowed as an actual worker state. */
+/* It will not work e.g. when the status worker tries to show the state. */
+/* It is only used in rule extension data to indicate, that the */
+/* activation state should not be overwritten. */
+#define JK_LB_ACTIVATION_ACTIVE        (0)
+#define JK_LB_ACTIVATION_DISABLED      (1)
+#define JK_LB_ACTIVATION_STOPPED       (2)
+#define JK_LB_ACTIVATION_UNSET         (9)
+#define JK_LB_ACTIVATION_DEF           (JK_LB_ACTIVATION_ACTIVE)
+#define JK_LB_ACTIVATION_MAX           (JK_LB_ACTIVATION_STOPPED)
 #define JK_LB_ACTIVATION_TEXT_ACTIVE   ("ACT")
 #define JK_LB_ACTIVATION_TEXT_DISABLED ("DIS")
 #define JK_LB_ACTIVATION_TEXT_STOPPED  ("STP")
+#define JK_LB_ACTIVATION_TEXT_DEF      (JK_LB_ACTIVATION_TEXT_ACTIVE)
 
 #define JK_LB_UINT64_STR_SZ          (21)
 #define JK_LB_NOTES_COUNT            (9)
@@ -103,33 +134,65 @@ extern "C"
 /* The exponent x is JK_LB_DECAY_MULT*#MAINT_INTV_SINCE_LAST_MAINT */
 #define JK_LB_DECAY_MULT         (1)
 
-struct worker_record
+struct lb_sub_worker
 {
-    jk_worker_t      *w;
+    jk_worker_t *worker;
     /* Shared memory worker data */
-    jk_shm_worker_t  *s;
-    /* Current jvmRoute. Can be name or domain */
-    const char       *r;
+    jk_shm_lb_sub_worker_t *s;
+
+    char         name[JK_SHM_STR_SIZ+1];
+    /* Sequence counter starting at 0 and increasing
+     * every time we change the config
+     */
+    volatile unsigned int sequence;
+
+    /* route */
+    char    route[JK_SHM_STR_SIZ+1];
+    /* worker domain */
+    char    domain[JK_SHM_STR_SIZ+1];
+    /* worker redirect route */
+    char    redirect[JK_SHM_STR_SIZ+1];
+    /* worker distance */
+    int distance;
+    /* current activation state (config) of the worker */
+    int activation;
+    /* Current lb factor */
+    int lb_factor;
+    /* Current lb reciprocal factor */
+    jk_uint64_t lb_mult;
 };
-typedef struct worker_record worker_record_t;
+typedef struct lb_sub_worker lb_sub_worker_t;
 
 struct lb_worker
 {
-    worker_record_t *lb_workers;
-    unsigned int num_of_workers;
-    int          lbmethod;
-    int          lblock;
-    time_t       maintain_time;
-    unsigned int max_packet_size;
+    jk_worker_t worker;
+    /* Shared memory worker data */
+    jk_shm_lb_worker_t *s;
+
+    char         name[JK_SHM_STR_SIZ+1];
+    /* Sequence counter starting at 0 and increasing
+     * every time we change the config
+     */
+    volatile unsigned int sequence;
 
     jk_pool_t p;
     jk_pool_atom_t buf[TINY_POOL_SIZE];
 
-    jk_worker_t worker;
     JK_CRIT_SEC cs;
 
-    /* Shared memory worker data */
-    jk_shm_worker_t  *s;
+    lb_sub_worker_t *lb_workers;
+    unsigned int num_of_workers;
+    int          sticky_session;
+    int          sticky_session_force;
+    int          recover_wait_time;
+    int          max_reply_timeouts;
+    int          retries;
+    int          lbmethod;
+    int          lblock;
+    int          maintain_time;
+    unsigned int max_packet_size;
+    unsigned int next_offset;
+
 };
 typedef struct lb_worker lb_worker_t;
 
@@ -137,10 +200,17 @@ int JK_METHOD lb_worker_factory(jk_worker_t **w,
                                 const char *name, jk_logger_t *l);
 
 const char *jk_lb_get_lock(lb_worker_t *p, jk_logger_t *l);
+int jk_lb_get_lock_code(const char *v);
 const char *jk_lb_get_method(lb_worker_t *p, jk_logger_t *l);
-const char *jk_lb_get_state(worker_record_t *p, jk_logger_t *l);
-const char *jk_lb_get_activation(worker_record_t *p, jk_logger_t *l);
+int jk_lb_get_method_code(const char *v);
+const char *jk_lb_get_state(lb_sub_worker_t *p, jk_logger_t *l);
+int jk_lb_get_state_code(const char *v);
+const char *jk_lb_get_activation_direct(int activation, jk_logger_t *l);
+const char *jk_lb_get_activation(lb_sub_worker_t *p, jk_logger_t *l);
+int jk_lb_get_activation_code(const char *v);
 void reset_lb_values(lb_worker_t *p, jk_logger_t *l);
+void jk_lb_pull(lb_worker_t * p, jk_logger_t *l);
+void jk_lb_push(lb_worker_t * p, jk_logger_t *l);
 void update_mult(lb_worker_t * p, jk_logger_t *l);
 
 #ifdef __cplusplus
