@@ -22,7 +22,7 @@
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Dan Milstein <danmil@shore.net>                            *
  * Author:      Henri Gomez <hgomez@apache.org>                            *
- * Version:     $Revision: 548791 $                                          *
+ * Version:     $Revision: 613546 $                                          *
  ***************************************************************************/
 
 #ifndef JK_SERVICE_H
@@ -51,6 +51,9 @@ extern "C"
 struct jk_worker_env
 {
 
+    /* The original configuration map */
+    jk_map_t *init_data;
+
     /* The URI to WORKER map, will be feeded by AJP14 autoconf feature */
     jk_uri_worker_map_t *uri_to_worker;
 
@@ -72,6 +75,21 @@ typedef struct jk_ws_service jk_ws_service_t;
 typedef struct jk_endpoint jk_endpoint_t;
 typedef struct jk_worker jk_worker_t;
 
+struct svc_extension
+{
+    /* reply_timeout overwrite */
+    int reply_timeout;
+    /* activation state overwrites for load balancers */
+    /* Dynamically allocated array with one entry per lb member. */
+    int *activation;
+    /* fail_on_status overwrites */
+    /* Number of elements in the array fail_on_status. */
+    int fail_on_status_size;
+    /* Dynamically allocated array with one entry per status. */
+    int *fail_on_status;
+};
+typedef struct svc_extension svc_extension_t;
+
 /*
  * The web server service 'class'.  An instance of this class is created
  * for each request which is forwarded from the web server to the servlet
@@ -208,10 +226,6 @@ struct jk_ws_service
     jk_msg_buf_t *reco_buf;
     int reco_status;
 
-    /* Number of retries. Defaults to JK_RETRIES
-     */
-    int retries;
-
     /*
      * If set call flush after each write
      */
@@ -222,6 +236,16 @@ struct jk_ws_service
      */
     int flush_header;
 
+    /*
+     * service extensions
+     */
+    svc_extension_t extension;
+
+    /*
+     * JK_TRUE if response headers have been sent back
+     */
+    int response_started;
+
     /*
      * HTTP status sent from container.
      */
@@ -278,6 +302,21 @@ struct jk_ws_service
                                       const char *const *log_names,
                                       const char *const *log_values,
                                       unsigned num_of_items);
+
+    /*
+     * Iterate through all vhosts
+     */
+    void *(JK_METHOD * next_vhost) (void *d);
+
+    /*
+     * String representation of a vhost
+     */
+    void (JK_METHOD * vhost_to_text) (void *d, char *buf, size_t len);
+
+    /*
+     * Get uw_map associated with a vhost
+     */
+    jk_uri_worker_map_t *(JK_METHOD * vhost_to_uw_map) (void *d);
 };
 
 /*
@@ -315,6 +354,14 @@ struct jk_endpoint
     jk_uint64_t rd;
     jk_uint64_t wr;
 
+    /*
+     * Flag to pass back recoverability status from
+     * a load balancer member to the load balancer itself.
+     * Depending on the configuration and request status
+     * recovery is not allowed.
+     */
+    int recoverable;
+
     /*
      * A 'this' pointer which is used by the subclasses of this class to
      * point to data/functions which are specific to a given protocol
@@ -387,11 +434,6 @@ struct jk_endpoint
 struct jk_worker
 {
 
-    /*
-     * Public property to enable the number of retry attempts
-     * on this worker.
-     */
-    int retries;
     /*
      * A 'this' pointer which is used by the subclasses of this class to
      * point to data/functions which are specific to a given protocol
