@@ -1,9 +1,10 @@
 /*
- *  Copyright 1999-2005 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -18,7 +19,7 @@
  * Description: Shared Memory object header file                           *
  * Author:      Mladen Turk <mturk@jboss.com>                              *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 441427 $                                           *
+ * Version:     $Revision: 611673 $                                           *
  ***************************************************************************/
 #ifndef _JK_SHM_H
 #define _JK_SHM_H
@@ -40,7 +41,7 @@ extern "C"
  */
 
 #define JK_SHM_MAJOR    '1'
-#define JK_SHM_MINOR    '2'
+#define JK_SHM_MINOR    '3'
 #define JK_SHM_STR_SIZ  63
 #define JK_SHM_URI_SIZ  127
 #define JK_SHM_DYNAMIC  16
@@ -48,26 +49,77 @@ extern "C"
 #define JK_SHM_MAGIC_SIZ  8
 
 /* Really huge numbers, but 64 workers should be enough */
-#define JK_SHM_MAX_WORKERS  64
-#define JK_SHM_WORKER_SIZE  JK_SHM_ALIGN(sizeof(jk_shm_worker_t))
-#define JK_SHM_DEF_SIZE     (JK_SHM_MAX_WORKERS * JK_SHM_WORKER_SIZE)
-#define JK_SHM_ALIGNMENT    64
-#define JK_SHM_ALIGN(x)     JK_ALIGN(x, JK_SHM_ALIGNMENT)
+#define JK_SHM_MAX_WORKERS        64
+#define JK_SHM_ALIGNMENT          64
+#define JK_SHM_ALIGN(x)           JK_ALIGN((x), JK_SHM_ALIGNMENT)
+#define JK_SHM_AJP_WORKER_SIZE    JK_SHM_ALIGN(sizeof(jk_shm_ajp_worker_t))
+#define JK_SHM_LB_SUB_WORKER_SIZE JK_SHM_ALIGN(sizeof(jk_shm_lb_sub_worker_t))
+#define JK_SHM_LB_WORKER_SIZE     JK_SHM_ALIGN(sizeof(jk_shm_lb_worker_t))
+#define JK_SHM_AJP_SIZE(x)        ((x) * JK_SHM_AJP_WORKER_SIZE)
+#define JK_SHM_LB_SUB_SIZE(x)     ((x) * JK_SHM_LB_SUB_WORKER_SIZE)
+#define JK_SHM_LB_SIZE(x)         ((x) * JK_SHM_LB_WORKER_SIZE)
+#define JK_SHM_DEF_SIZE           JK_SHM_AJP_SIZE(JK_SHM_MAX_WORKERS) + JK_SHM_LB_SUB_SIZE(JK_SHM_MAX_WORKERS) + JK_SHM_LB_SIZE(JK_SHM_MAX_WORKERS)
 
-/** jk shm worker record structure */
-struct jk_shm_worker
+/** jk shm generic worker record structure */
+struct jk_shm_worker_header
 {
     int     id;
+    int     type;
+    /* worker name */
+    char    name[JK_SHM_STR_SIZ+1];
+    /* Sequence counter starting at 0 and increasing
+     * every time we change the config
+     */
+    volatile unsigned int sequence;
+};
+typedef struct jk_shm_worker_header jk_shm_worker_header_t;
+
+/** jk shm ajp13/ajp14 worker record structure */
+struct jk_shm_ajp_worker
+{
+    jk_shm_worker_header_t h;
+
+    /* Configuration data mirrored from ajp_worker */
+    int cache_timeout;
+    int connect_timeout;
+    int reply_timeout;
+    int prepost_timeout;
+    unsigned int recovery_opts;
+    int retries;
+    unsigned int max_packet_size;
+    /* current error state (runtime) of the worker */
+    volatile int state;
+    /* Statistical data */
     /* Number of currently busy channels */
     volatile int busy;
     /* Maximum number of busy channels */
     volatile int max_busy;
-    /* Number of currently connected channels */
-    volatile int connected;
-    /* worker name */
-    char    name[JK_SHM_STR_SIZ+1];
-    /* jvm route */
-    char    jvm_route[JK_SHM_STR_SIZ+1];
+    volatile time_t  error_time;
+    /* Number of bytes read from remote */
+    volatile jk_uint64_t readed;
+    /* Number of bytes transferred to remote */
+    volatile jk_uint64_t transferred;
+    /* Number of times the worker was used */
+    volatile jk_uint64_t  used;
+    /* Number of times the worker was used - snapshot during maintenance */
+    volatile jk_uint64_t  used_snapshot;
+    /* Number of non 200 responses */
+    volatile jk_uint32_t  errors;
+    /* Decayed number of reply_timeout errors */
+    volatile jk_uint32_t  reply_timeouts;
+    /* Number of client errors */
+    volatile jk_uint32_t  client_errors;
+    volatile time_t  last_maintain_time;
+};
+typedef struct jk_shm_ajp_worker jk_shm_ajp_worker_t;
+
+/** jk shm lb sub worker record structure */
+struct jk_shm_lb_sub_worker
+{
+    jk_shm_worker_header_t h;
+
+    /* route */
+    char    route[JK_SHM_STR_SIZ+1];
     /* worker domain */
     char    domain[JK_SHM_STR_SIZ+1];
     /* worker redirect route */
@@ -84,35 +136,41 @@ struct jk_shm_worker
     volatile jk_uint64_t lb_mult;
     /* Current lb value  */
     volatile jk_uint64_t lb_value;
-    int     sticky_session;
-    int     sticky_session_force;
-    int     recover_wait_time;
-    int     retries;
     /* Statistical data */
     volatile time_t  error_time;
-    /* Service transfer rate time */
-    volatile time_t  last_maintain_time;
-    /* Number of bytes read from remote */
-    volatile jk_uint64_t readed;
-    /* Number of bytes transferred to remote */
-    volatile jk_uint64_t transferred;
-    /* Number of times the worker was elected */
-    volatile jk_uint64_t  elected;
     /* Number of times the worker was elected - snapshot during maintenance */
     volatile jk_uint64_t  elected_snapshot;
     /* Number of non 200 responses */
     volatile jk_uint32_t  errors;
-    /* Number of recovery attempts */
-    volatile jk_uint32_t  recoveries;
-    /* Number of recovery failures */
-    volatile jk_uint32_t  recovery_errors;
-    /* Number of client errors */
-    volatile jk_uint32_t  client_errors;
 };
-typedef struct jk_shm_worker jk_shm_worker_t;
+typedef struct jk_shm_lb_sub_worker jk_shm_lb_sub_worker_t;
+
+/** jk shm lb worker record structure */
+struct jk_shm_lb_worker
+{
+    jk_shm_worker_header_t h;
+
+    /* Number of currently busy channels */
+    volatile int busy;
+    /* Maximum number of busy channels */
+    volatile int max_busy;
+    int     sticky_session;
+    int     sticky_session_force;
+    int     recover_wait_time;
+    int     max_reply_timeouts;
+    int     retries;
+    int     lbmethod;
+    int     lblock;
+    unsigned int max_packet_size;
+    volatile time_t  last_maintain_time;
+};
+typedef struct jk_shm_lb_worker jk_shm_lb_worker_t;
 
 const char *jk_shm_name(void);
 
+/* Calculate needed shm size */
+size_t jk_shm_calculate_size(jk_map_t *init_data, jk_logger_t *l);
+
 /* Open the shared memory creating file if needed
  */
 int jk_shm_open(const char *fname, size_t sz, jk_logger_t *l);
@@ -131,10 +189,20 @@ int jk_shm_attach(const char *fname, size_t sz, jk_logger_t *l);
  */
 void *jk_shm_alloc(jk_pool_t *p, size_t size);
 
-/* allocate shm worker record
+/* allocate shm ajp worker record
  * If there is no shm present the pool will be used instead
  */
-jk_shm_worker_t *jk_shm_alloc_worker(jk_pool_t *p);
+jk_shm_ajp_worker_t *jk_shm_alloc_ajp_worker(jk_pool_t *p);
+
+/* allocate shm lb sub worker record
+ * If there is no shm present the pool will be used instead
+ */
+jk_shm_lb_sub_worker_t *jk_shm_alloc_lb_sub_worker(jk_pool_t *p);
+
+/* allocate shm lb worker record
+ * If there is no shm present the pool will be used instead
+ */
+jk_shm_lb_worker_t *jk_shm_alloc_lb_worker(jk_pool_t *p);
 
 /* Return workers.properties last modified time
  */
