@@ -20,7 +20,7 @@
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Henri Gomez <hgomez@apache.org>                            *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 559693 $                                          *
+ * Version:     $Revision: 613568 $                                          *
  ***************************************************************************/
 
 
@@ -43,6 +43,7 @@
 #define LIBPATH_OF_WORKER           ("ld_path")
 #define CMD_LINE_OF_WORKER          ("cmd_line")
 #define NATIVE_LIB_OF_WORKER        ("native_lib")
+#define REFERENCE_OF_WORKER         ("reference")
 #define HOST_OF_WORKER              ("host")
 #define PORT_OF_WORKER              ("port")
 #define TYPE_OF_WORKER              ("type")
@@ -123,7 +124,7 @@
 /*
  * define the log format, we're using by default the one from error.log
  *
- * [Mon Mar 26 19:44:48 2001] [jk_uri_worker_map.c (155)]: Into jk_uri_worker_map_t::uri_worker_map_alloc
+ * [Mon Mar 26 19:44:48.123 2001] [jk_uri_worker_map.c (155)]: Into jk_uri_worker_map_t::uri_worker_map_alloc
  * log format used by apache in error.log
  */
 #define JK_TIME_CONV_MILLI    "%Q"
@@ -136,7 +137,6 @@
 #define JK_TIME_SUBSEC_NONE   (0)
 #define JK_TIME_SUBSEC_MILLI  (1)
 #define JK_TIME_SUBSEC_MICRO  (2)
-#define JK_TIME_MAX_SIZE      (64)
 
 /* Visual C++ Toolkit 2003 support */
 #if defined (_MSC_VER) && (_MSC_VER == 1310)
@@ -157,6 +157,7 @@ static const char *list_properties[] = {
 
 static const char *unique_properties[] = {
     SECRET_OF_WORKER,
+    REFERENCE_OF_WORKER,
     HOST_OF_WORKER,
     PORT_OF_WORKER,
     TYPE_OF_WORKER,
@@ -239,6 +240,7 @@ static const char *supported_properties[] = {
     LIBPATH_OF_WORKER,
     CMD_LINE_OF_WORKER,
     NATIVE_LIB_OF_WORKER,
+    REFERENCE_OF_WORKER,
     HOST_OF_WORKER,
     PORT_OF_WORKER,
     TYPE_OF_WORKER,
@@ -350,12 +352,20 @@ void jk_sleep(int ms)
 #endif
 }
 
+/* Replace the first occurence of a sub second time format character
+ * by a series of zero digits with the right precision.
+ * We format our timestamp with strftime, but this can not handle
+ * sub second timestamps.
+ * So we first patch the milliseconds or microseconds literally into
+ * the format string, and then pass it on the strftime.
+ * In order to do that efficiently, we prepare a format string, that
+ * already has placeholder digits for the sub second time stamp
+ * and we save the position and time precision of this placeholder.
+ */
 void jk_set_time_fmt(jk_logger_t *l, const char *jk_log_fmt)
 {
     if (l) {
         char *s;
-        char log_fmt_safe[JK_TIME_MAX_SIZE];
-        char *fmt;
 
         if (!jk_log_fmt) {
 #ifndef NO_GETTIMEOFDAY
@@ -367,43 +377,58 @@ void jk_set_time_fmt(jk_logger_t *l, const char *jk_log_fmt)
         l->log_fmt_type = JK_TIME_SUBSEC_NONE;
         l->log_fmt_offset = 0;
         l->log_fmt_size = 0;
-        l->log_fmt_subsec = jk_log_fmt;
         l->log_fmt = jk_log_fmt;
 
-        fmt = (char *)malloc(JK_TIME_MAX_SIZE + strlen(JK_TIME_PATTERN_MICRO));
-        if (fmt) {
-            strncpy(log_fmt_safe, jk_log_fmt, JK_TIME_MAX_SIZE);
-            if ((s = strstr(log_fmt_safe, JK_TIME_CONV_MILLI))) {
-                size_t offset = s - log_fmt_safe;
-                size_t len = strlen(JK_TIME_PATTERN_MILLI);
+/* Look for the first occurence of JK_TIME_CONV_MILLI */
+        if ((s = strstr(jk_log_fmt, JK_TIME_CONV_MILLI))) {
+            size_t offset = s - jk_log_fmt;
+            size_t len = strlen(JK_TIME_PATTERN_MILLI);
 
+/* If we don't have enough space in our fixed-length char array,
+ * we simply stick to the default format, ignoring JK_TIME_CONV_MILLI.
+ * Otherwise we replace the first occurence of JK_TIME_CONV_MILLI by JK_TIME_PATTERN_MILLI.
+ */
+            if (offset + len < JK_TIME_MAX_SIZE) {
                 l->log_fmt_type = JK_TIME_SUBSEC_MILLI;
                 l->log_fmt_offset = offset;
-                strncpy(fmt, log_fmt_safe, offset);
-                strncpy(fmt + offset, JK_TIME_PATTERN_MILLI, len);
-                strncpy(fmt + offset + len,
+                strncpy(l->log_fmt_subsec, jk_log_fmt, offset);
+                strncpy(l->log_fmt_subsec + offset, JK_TIME_PATTERN_MILLI, len);
+                strncpy(l->log_fmt_subsec + offset + len,
                         s + strlen(JK_TIME_CONV_MILLI),
-                        JK_TIME_MAX_SIZE - offset - len);
-                fmt[JK_TIME_MAX_SIZE-1] = '\0';
-                l->log_fmt_subsec = fmt;
-                l->log_fmt_size = strlen(fmt);
+                        JK_TIME_MAX_SIZE - offset - len - 1);
+/* Now we put a stop mark into the string to make it's length at most JK_TIME_MAX_SIZE-1
+ * plus terminating '\0'.
+ */
+                l->log_fmt_subsec[JK_TIME_MAX_SIZE-1] = '\0';
+                l->log_fmt_size = strlen(l->log_fmt_subsec);
             }
-            else if ((s = strstr(log_fmt_safe, JK_TIME_CONV_MICRO))) {
-                size_t offset = s - log_fmt_safe;
-                size_t len = strlen(JK_TIME_PATTERN_MICRO);
+/* Look for the first occurence of JK_TIME_CONV_MICRO */
+        }
+        else if ((s = strstr(jk_log_fmt, JK_TIME_CONV_MICRO))) {
+            size_t offset = s - jk_log_fmt;
+            size_t len = strlen(JK_TIME_PATTERN_MICRO);
 
+/* If we don't have enough space in our fixed-length char array,
+ * we simply stick to the default format, ignoring JK_TIME_CONV_MICRO.
+ * Otherwise we replace the first occurence of JK_TIME_CONV_MICRO by JK_TIME_PATTERN_MICRO.
+ */
+            if (offset + len < JK_TIME_MAX_SIZE) {
                 l->log_fmt_type = JK_TIME_SUBSEC_MICRO;
                 l->log_fmt_offset = offset;
-                strncpy(fmt, log_fmt_safe, offset);
-                strncpy(fmt + offset, JK_TIME_PATTERN_MICRO, len);
-                strncpy(fmt + offset + len,
+                strncpy(l->log_fmt_subsec, jk_log_fmt, offset);
+                strncpy(l->log_fmt_subsec + offset, JK_TIME_PATTERN_MICRO, len);
+                strncpy(l->log_fmt_subsec + offset + len,
                         s + strlen(JK_TIME_CONV_MICRO),
-                        JK_TIME_MAX_SIZE - offset - len);
-                fmt[JK_TIME_MAX_SIZE-1] = '\0';
-                l->log_fmt_subsec = fmt;
-                l->log_fmt_size = strlen(fmt);
+                        JK_TIME_MAX_SIZE - offset - len - 1);
+/* Now we put a stop mark into the string to make it's length at most JK_TIME_MAX_SIZE-1
+ * plus terminating '\0'.
+ */
+                l->log_fmt_subsec[JK_TIME_MAX_SIZE-1] = '\0';
+                l->log_fmt_size = strlen(l->log_fmt_subsec);
             }
         }
+        jk_log(l, JK_LOG_DEBUG, "Pre-processed log time stamp format is '%s'",
+               l->log_fmt_type == JK_TIME_SUBSEC_NONE ? l->log_fmt : l->log_fmt_subsec);
     }
 }
 
@@ -411,7 +436,15 @@ static int set_time_str(char *str, int len, jk_logger_t *l)
 {
     time_t t;
     struct tm *tms;
+#ifdef _MT_CODE_PTHREAD
+    struct tm res;
+#endif
     int done;
+/* We want to use a fixed maximum size buffer here.
+ * If we would dynamically adjust it to the real format
+ * string length, we could support longer format strings,
+ * but we would have to allocate and free for each log line.
+ */
     char log_fmt[JK_TIME_MAX_SIZE];
 
     if (!l || !l->log_fmt) {
@@ -431,6 +464,11 @@ static int set_time_str(char *str, int len, jk_logger_t *l)
         rc = gettimeofday(&tv, NULL);
 #endif
         if (rc == 0) {
+/* We need this subsec buffer, because we convert
+ * the integer with sprintf(), but we don't
+ * want to write the terminating '\0' into our
+ * final log format string.
+ */
             char subsec[7];
             t = tv.tv_sec;
             strncpy(log_fmt, l->log_fmt_subsec, l->log_fmt_size + 1);
@@ -453,7 +491,11 @@ static int set_time_str(char *str, int len, jk_logger_t *l)
 #else
     t = time(NULL);
 #endif
+#ifdef _MT_CODE_PTHREAD
+    tms = localtime_r(&t, &res);
+#else
     tms = localtime(&t);
+#endif
     if (log_fmt[0])
         done = (int)strftime(str, len, log_fmt, tms);
     else
@@ -518,7 +560,6 @@ int jk_open_file_logger(jk_logger_t **l, const char *file, int level)
         if (rc && p) {
             rc->log = log_to_file;
             rc->level = level;
-            jk_set_time_fmt(rc, NULL);
             rc->logger_private = p;
 #if defined(AS400) && !defined(AS400_UTF8)
             p->logfile = fopen(file, "a+, o_ccsid=0");
@@ -527,7 +568,7 @@ int jk_open_file_logger(jk_logger_t **l, const char *file, int level)
 #endif
             if (p->logfile) {
                 *l = rc;
-                jk_log(rc, JK_LOG_DEBUG, "log time stamp format is '%s'", rc->log_fmt);
+                jk_set_time_fmt(rc, NULL);
                 return JK_TRUE;
             }
         }
@@ -1719,10 +1760,24 @@ int jk_get_worker_libpath(jk_map_t *m, const char *wname, const char **libpath)
     return JK_FALSE;
 }
 
+int is_http_status_fail(unsigned int http_status_fail_num,
+                        int *http_status_fail, int status)
+{
+    unsigned int i;
+    int soft_status = -1 * status;
+    for (i = 0; i < http_status_fail_num; i++) {
+        if (http_status_fail[i] == status)
+            return 1;
+        else if (http_status_fail[i] == soft_status)
+            return -1;
+    }
+    return 0;
+}
+
 char **jk_parse_sysprops(jk_pool_t *p, const char *sysprops)
 {
     char **rc = NULL;
-#ifdef _REENTRANT
+#ifdef _MT_CODE_PTHREAD
     char *lasts;
 #endif
 
@@ -1740,7 +1795,7 @@ char **jk_parse_sysprops(jk_pool_t *p, const char *sysprops)
             rc = jk_pool_alloc(p, (num_of_prps + 1) * sizeof(char *));
             if (rc) {
                 unsigned i = 0;
-#ifdef _REENTRANT
+#ifdef _MT_CODE_PTHREAD
                 char *tmp = strtok_r(prps, "*", &lasts);
 #else
                 char *tmp = strtok(prps, "*");
@@ -1748,7 +1803,7 @@ char **jk_parse_sysprops(jk_pool_t *p, const char *sysprops)
 
                 while (tmp && i < num_of_prps) {
                     rc[i] = tmp;
-#ifdef _REENTRANT
+#ifdef _MT_CODE_PTHREAD
                     tmp = strtok_r(NULL, "*", &lasts);
 #else
                     tmp = strtok(NULL, "*");
@@ -1813,6 +1868,7 @@ void jk_init_ws_service(jk_ws_service_t *s)
     s->ssl_cert_len = 0;
     s->ssl_cipher = NULL;
     s->ssl_session = NULL;
+    s->ssl_key_size = -1;
     s->headers_names = NULL;
     s->headers_values = NULL;
     s->num_headers = 0;
@@ -1820,8 +1876,27 @@ void jk_init_ws_service(jk_ws_service_t *s)
     s->attributes_values = NULL;
     s->num_attributes = 0;
     s->route = NULL;
-    s->retries = JK_RETRIES;
+    s->secret = NULL;
+    s->reco_buf = NULL;
+    s->reco_status = RECO_NONE;
+    s->flush_packets = JK_FALSE;
+    s->flush_header = JK_FALSE;
+    s->extension.reply_timeout = -1;
+    s->extension.activation = NULL;
+    s->extension.fail_on_status_size = 0;
+    s->extension.fail_on_status = NULL;
+    s->response_started = JK_FALSE;
+    s->http_response_status = JK_HTTP_OK;
+    s->uw_map = NULL;
+    s->start_response = NULL;
+    s->read = NULL;
+    s->write = NULL;
+    s->flush = NULL;
+    s->disable_reuse = JK_FALSE;
     s->add_log_items = NULL;
+    s->next_vhost = NULL;
+    s->vhost_to_text = NULL;
+    s->vhost_to_uw_map = NULL;
 }
 
 #ifdef _MT_CODE_PTHREAD
