@@ -1,9 +1,10 @@
 /*
- *  Copyright 1999-2004 The Apache Software Foundation
- *
- *  Licensed under the Apache License, Version 2.0 (the "License");
- *  you may not use this file except in compliance with the License.
- *  You may obtain a copy of the License at
+ *  Licensed to the Apache Software Foundation (ASF) under one or more
+ *  contributor license agreements.  See the NOTICE file distributed with
+ *  this work for additional information regarding copyright ownership.
+ *  The ASF licenses this file to You under the Apache License, Version 2.0
+ *  (the "License"); you may not use this file except in compliance with
+ *  the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -19,7 +20,7 @@
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Henri Gomez <hgomez@apache.org>                            *
  * Author:      Rainer Jung <rjung@apache.org>                             *
- * Version:     $Revision: 439824 $                                          *
+ * Version:     $Revision: 613546 $                                          *
  ***************************************************************************/
 #ifndef _JK_UTIL_H
 #define _JK_UTIL_H
@@ -32,8 +33,14 @@
 
 #define JK_SLEEP_DEF     (100)
 
+const char *jk_get_bool(int v);
+
+int jk_get_bool_code(const char *v, int def);
+
 void jk_sleep(int ms);
 
+void jk_set_time_fmt(jk_logger_t *l, const char *jk_log_fmt);
+
 int jk_parse_log_level(const char *level);
 
 int jk_open_file_logger(jk_logger_t **l, const char *file, int level);
@@ -81,7 +88,9 @@ int jk_get_worker_recycle_timeout(jk_map_t *m, const char *wname, int def);
 
 int jk_get_worker_recover_timeout(jk_map_t *m, const char *wname, int def);
 
-const char *jk_get_worker_jvm_route(jk_map_t *m, const char *wname, const char *def);
+int jk_get_worker_max_reply_timeouts(jk_map_t *m, const char *wname, int def);
+
+const char *jk_get_worker_route(jk_map_t *m, const char *wname, const char *def);
 
 const char *jk_get_worker_domain(jk_map_t *m, const char *wname, const char *def);
 
@@ -97,9 +106,7 @@ int jk_get_is_worker_stopped(jk_map_t *m, const char *wname);
 
 int jk_get_worker_activation(jk_map_t *m, const char *wname);
 
-void jk_set_log_format(const char *logformat);
-
-int jk_get_worker_list(jk_map_t *m, char ***list, unsigned *num_of_wokers);
+int jk_get_worker_list(jk_map_t *m, char ***list, unsigned *num_of_workers);
 
 int jk_get_lb_factor(jk_map_t *m, const char *wname);
 
@@ -115,7 +122,7 @@ int jk_get_lb_lock(jk_map_t *m, const char *wname);
 
 int jk_get_lb_worker_list(jk_map_t *m,
                           const char *lb_wname,
-                          char ***list, unsigned int *num_of_wokers);
+                          char ***list, unsigned int *num_of_workers);
 int jk_get_worker_mount_list(jk_map_t *m,
                              const char *wname,
                              char ***list, unsigned int *num_of_maps);
@@ -149,6 +156,8 @@ int jk_is_unique_property(const char *prp_name);
 
 int jk_is_deprecated_property(const char *prp_name);
 
+int jk_is_valid_property(const char *prp_name);
+
 int jk_get_worker_stdout(jk_map_t *m, const char *wname, const char **stdout_name);
 
 int jk_get_worker_stderr(jk_map_t *m, const char *wname, const char **stderr_name);
@@ -170,12 +179,62 @@ int jk_get_worker_maintain_time(jk_map_t *m);
 
 int jk_get_max_packet_size(jk_map_t *m, const char *wname);
 
+const char *jk_get_worker_style_sheet(jk_map_t *m, const char *wname, const char *def);
+
+int jk_get_is_read_only(jk_map_t *m, const char *wname);
+
+int jk_get_worker_user_list(jk_map_t *m,
+                            const char *wname,
+                            char ***list, unsigned int *num);
+
+int jk_get_worker_good_rating(jk_map_t *m,
+                              const char *wname,
+                              char ***list, unsigned int *num);
+
+int jk_get_worker_bad_rating(jk_map_t *m,
+                             const char *wname,
+                             char ***list, unsigned int *num);
+
+const char *jk_get_worker_name_space(jk_map_t *m, const char *wname, const char *def);
+
+const char *jk_get_worker_xmlns(jk_map_t *m, const char *wname, const char *def);
+
+const char *jk_get_worker_xml_doctype(jk_map_t *m, const char *wname, const char *def);
+
+const char *jk_get_worker_prop_prefix(jk_map_t *m, const char *wname, const char *def);
+
+int jk_get_worker_fail_on_status(jk_map_t *m, const char *wname,
+                                 int *list, unsigned int list_size);
+
+int jk_get_worker_user_case_insensitive(jk_map_t *m, const char *wname);
+
+int is_http_status_fail(unsigned int http_status_fail_num,
+                        int *http_status_fail, int status);
+
 #define TC32_BRIDGE_TYPE    32
 #define TC33_BRIDGE_TYPE    33
 #define TC40_BRIDGE_TYPE    40
 #define TC41_BRIDGE_TYPE    41
 #define TC50_BRIDGE_TYPE    50
 
+#ifdef AS400
+
+#define S_IFREG _S_IFREG
+
+#ifdef AS400_UTF8
+
+void jk_ascii2ebcdic(char *src, char *dst);
+void jk_ebcdic2ascii(char *src, char *dst);
+
+#endif /* AS400_UTF8 */
+
+#endif
+
+/* i5/OS V5R4 need ASCII-EBCDIC conversion before stat() call */
+/* added a stat() mapper function, jk_stat, for such purpose */
+
+int jk_stat(const char *f, struct stat * statbuf);
+
 #ifdef __cplusplus
 extern "C"
 {
