@@ -21,7 +21,7 @@
  * Author:      Larry Isaacs <larryi@apache.org>                           *
  * Author:      Ignacio J. Ortega <nacho@apache.org>                       *
  * Author:      Mladen Turk <mturk@apache.org>                             *
- * Version:     $Revision: 562198 $                                        *
+ * Version:     $Revision: 613274 $                                        *
  ***************************************************************************/
 
 // This define is needed to include wincrypt,h, needed to get client certificates
@@ -112,6 +112,7 @@ static char HTTP_WORKER_HEADER_NAME[MAX_PATH];
 #define BAD_REQUEST     -1
 #define BAD_PATH        -2
 #define MAX_SERVERNAME  128
+#define MAX_PACKET_SIZE 65536
 
 char HTML_ERROR_400[] =         "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">\n"
                                 "<HTML><HEAD><TITLE>Bad request!</TITLE></HEAD>\n"
@@ -145,7 +146,7 @@ char HTML_ERROR_503[] =         "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Tr
 #define GET_SERVER_VARIABLE_VALUE(name, place)          \
   do {                                                  \
     (place) = NULL;                                     \
-    huge_buf_sz = sizeof(huge_buf);                     \
+    huge_buf_sz = MAX_PACKET_SIZE;                      \
     if (get_server_value(private_data->lpEcb,           \
                         (name),                         \
                         huge_buf,                       \
@@ -156,7 +157,7 @@ char HTML_ERROR_503[] =         "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Tr
 
 #define GET_SERVER_VARIABLE_VALUE_INT(name, place, def)     \
   do {                                                      \
-    huge_buf_sz = sizeof(huge_buf);                         \
+    huge_buf_sz = MAX_PACKET_SIZE;                          \
     if (get_server_value(private_data->lpEcb,               \
                         (name),                             \
                         huge_buf,                           \
@@ -192,7 +193,7 @@ static char worker_file[MAX_PATH * 2];
 static char worker_mount_file[MAX_PATH * 2] = {0};
 static int  worker_mount_reload = JK_URIMAP_DEF_RELOAD;
 static char rewrite_rule_file[MAX_PATH * 2] = {0};
-static int shm_config_size = JK_SHM_DEF_SIZE;
+static size_t shm_config_size = 0;
 static int strip_session = 0;
 static DWORD auth_notification_flags = 0;
 static int   use_auth_notification_flags = 1;
@@ -212,7 +213,6 @@ struct isapi_private_data_t
 {
     jk_pool_t p;
 
-    int request_started;
     unsigned int bytes_read_so_far;
     LPEXTENSION_CONTROL_BLOCK lpEcb;
 };
@@ -587,12 +587,12 @@ static int JK_METHOD start_response(jk_ws_service_t *s,
     if (s && s->ws_private) {
         int rv = JK_TRUE;
         isapi_private_data_t *p = s->ws_private;
-        if (!p->request_started) {
+        if (!s->response_started) {
             char *status_str;
             DWORD status_str_len;
             char *headers_str = NULL;
             BOOL keep_alive = FALSE;
-            p->request_started = JK_TRUE;
+            s->response_started = JK_TRUE;
 
             /*
              * Create the status line
@@ -743,7 +743,7 @@ static int JK_METHOD write(jk_ws_service_t *s, const void *b, unsigned int l)
             unsigned int written = 0;
             char *buf = (char *)b;
 
-            if (!p->request_started) {
+            if (!s->response_started) {
                 start_response(s, 200, NULL, NULL, NULL, 0);
             }
 
@@ -1261,19 +1261,10 @@ DWORD WINAPI HttpFilterProc(PHTTP_FILTER_CONTEXT pfc,
             }
             if (szHost > 0) {
                 StringCbCat(snuri, INTERNET_MAX_URL_LENGTH, Host);
-                StringCbCat(snuri, INTERNET_MAX_URL_LENGTH, uri);
-                if (JK_IS_DEBUG_LEVEL(logger))
-                    jk_log(logger, JK_LOG_DEBUG,
-                           "Virtual Host redirection of %s",
-                           snuri);
-                worker = map_uri_to_worker(uw_map, snuri, logger);
+                worker = map_uri_to_worker(uw_map, uri, snuri, logger);
             }
-            if (!worker) {
-                if (JK_IS_DEBUG_LEVEL(logger))
-                    jk_log(logger, JK_LOG_DEBUG,
-                           "Default redirection of %s",
-                           uri);
-                worker = map_uri_to_worker(uw_map, uri, logger);
+            else {
+                worker = map_uri_to_worker(uw_map, uri, NULL, logger);
             }
             /*
              * Check if somebody is feading us with his own TOMCAT data headers.
@@ -1284,13 +1275,13 @@ DWORD WINAPI HttpFilterProc(PHTTP_FILTER_CONTEXT pfc,
 
                 if (JK_IS_DEBUG_LEVEL(logger))
                     jk_log(logger, JK_LOG_DEBUG,
-                           "check if [%s] is points to the web-inf directory",
+                           "check if [%s] points to the web-inf directory",
                         uri);
 
                 if (uri_is_web_inf(uri)) {
                     jk_log(logger, JK_LOG_EMERG,
                            "[%s] points to the web-inf or meta-inf directory. "
-                           "Somebody try to hack into the site!!!",
+                           "Somebody tries to hack into the site!!!",
                            uri);
 
                     write_error_response(pfc, "404 Not Found",
@@ -1313,7 +1304,7 @@ DWORD WINAPI HttpFilterProc(PHTTP_FILTER_CONTEXT pfc,
                         *(query - 1) = '\0';
                     if (JK_IS_DEBUG_LEVEL(logger))
                         jk_log(logger, JK_LOG_DEBUG,
-                               "fowarding original URI [%s]",
+                               "forwarding original URI [%s]",
                                uri);
                     forwardURI = uri;
                 }
@@ -1361,12 +1352,12 @@ DWORD WINAPI HttpFilterProc(PHTTP_FILTER_CONTEXT pfc,
                     StringCbCopy(duri, INTERNET_MAX_URL_LENGTH, forwardURI);
                     if (simple_rewrite(forwardURI)) {
                         jk_log(logger, JK_LOG_DEBUG,
-                               "rewriten URI [%s]->[%s]",
+                               "rewritten URI [%s]->[%s]",
                                duri, forwardURI);
                     }
                     else if (rregex_rewrite(forwardURI)) {
                         jk_log(logger, JK_LOG_DEBUG,
-                               "rewriten URI [%s]->[%s]",
+                               "rewritten URI [%s]->[%s]",
                                duri, forwardURI);
                     }
                 }
@@ -1499,7 +1490,6 @@ DWORD WINAPI HttpExtensionProc(LPEXTENSION_CONTROL_BLOCK lpEcb)
         jk_init_ws_service(&s);
         jk_open_pool(&private_data.p, buf, sizeof(buf));
 
-        private_data.request_started = JK_FALSE;
         private_data.bytes_read_so_far = 0;
         private_data.lpEcb = lpEcb;
 
@@ -1516,8 +1506,6 @@ DWORD WINAPI HttpExtensionProc(LPEXTENSION_CONTROL_BLOCK lpEcb)
 
             if (worker) {
                 jk_endpoint_t *e = NULL;
-                /* Update retries for this worker */
-                s.retries = worker->retries;
                 if (worker->get_endpoint(worker, &e, logger)) {
                     int is_error = JK_HTTP_SERVER_ERROR;
                     int result;
@@ -1604,8 +1592,8 @@ BOOL WINAPI TerminateFilter(DWORD dwFlags)
             }
             jk_map_free(&rregexp_map);
         }
-        jk_shm_close();
         wc_close(logger);
+        jk_shm_close();
         if (logger) {
             jk_close_file_logger(&logger);
         }
@@ -1681,10 +1669,6 @@ static int init_jk(char *serverName)
                 shm_name[i] = '_';
         }
     }
-    /*
-     * Create named shared memory for each server
-     */
-    jk_shm_open(shm_name, shm_config_size, logger);
 
     jk_set_worker_def_cache_size(DEFAULT_WORKER_THREADS);
 
@@ -1766,11 +1750,28 @@ static int init_jk(char *serverName)
         if (jk_map_alloc(&workers_map)) {
             if (jk_map_read_properties(workers_map, worker_file, NULL,
                                        JK_MAP_HANDLE_DUPLICATES, logger)) {
+                int rv;
+
                 /* we add the URI->WORKER MAP since workers using AJP14 will feed it */
 
                 if (jk_map_resolve_references(workers_map, "worker.", 1, 1, logger) == JK_FALSE) {
                     jk_log(logger, JK_LOG_ERROR, "Error in resolving configuration references");
                 }
+                /*
+                 * Create named shared memory for each server
+                 */
+                if (shm_config_size == 0)
+                    shm_config_size = jk_shm_calculate_size(workers_map, logger);
+                else {
+                    jk_log(logger, JK_LOG_WARNING,
+                           "The optimal shared memory size can now be determined automatically.");
+                    jk_log(logger, JK_LOG_WARNING,
+                           "You can remove the JkShmSize directive if you want to use the optimal size.");
+                }
+                if ((rv = jk_shm_open(shm_name, shm_config_size, logger)) != 0)
+                    jk_log(logger, JK_LOG_ERROR,
+                           "Initializing shm:%s errno=%d. Load balancing workers will not function properly.",
+                           jk_shm_name(), rv);
 
                 worker_env.uri_to_worker = uw_map;
                 worker_env.server_name = serverName;
@@ -1778,11 +1779,11 @@ static int init_jk(char *serverName)
                 if (wc_open(workers_map, &worker_env, logger)) {
                     rc = JK_TRUE;
                 }
+                uri_worker_map_ext(uw_map, logger);
             }
-            else {
+            else
                 jk_log(logger, JK_LOG_EMERG,
                        "Unable to read worker file %s.", worker_file);
-            }
             if (rc != JK_TRUE) {
                 jk_map_free(&workers_map);
                 workers_map = NULL;
@@ -1873,7 +1874,7 @@ static int read_registry_init_data(void)
             ok = JK_FALSE;
         }
     }
-    shm_config_size = get_config_int(src, SHM_SIZE_TAG, JK_SHM_DEF_SIZE);
+    shm_config_size = (size_t) get_config_int(src, SHM_SIZE_TAG, 0);
     worker_mount_reload = get_config_int(src, WORKER_MOUNT_RELOAD_TAG, JK_URIMAP_DEF_RELOAD);
     strip_session = get_config_bool(src, STRIP_SESSION_TAG, JK_FALSE);
     use_auth_notification_flags = get_config_int(src, AUTH_COMPLETE_TAG, 1);
@@ -1974,26 +1975,19 @@ static int get_registry_config_number(HKEY hkey,
 static int init_ws_service(isapi_private_data_t * private_data,
                            jk_ws_service_t *s, char **worker_name)
 {
-    char huge_buf[16 * 1024];   /* should be enough for all */
+    char *huge_buf = NULL;   /* should be enough for all */
 
     DWORD huge_buf_sz;
 
-    s->route = NULL;
-
     s->start_response = start_response;
     s->read = read;
     s->write = write;
 
-    /* Yes we do want to reuse AJP connections */
-    s->disable_reuse = JK_FALSE;
-
-    s->flush = NULL;
-    s->flush_packets = JK_FALSE;
-    s->flush_header = JK_FALSE;
-
-    /* Clear RECO status */
-    s->reco_status = RECO_NONE;
+    if (!(huge_buf = jk_pool_alloc(&private_data->p, MAX_PACKET_SIZE))) {
 
+        return JK_FALSE;    
+    }
+    huge_buf_sz = MAX_PACKET_SIZE;
     GET_SERVER_VARIABLE_VALUE(HTTP_WORKER_HEADER_NAME, (*worker_name));
     GET_SERVER_VARIABLE_VALUE(HTTP_URI_HEADER_NAME, s->req_uri);
     GET_SERVER_VARIABLE_VALUE(HTTP_QUERY_HEADER_NAME, s->query_string);
@@ -2020,15 +2014,6 @@ static int init_ws_service(isapi_private_data_t * private_data,
     s->method = private_data->lpEcb->lpszMethod;
     s->content_length = (jk_uint64_t)private_data->lpEcb->cbTotalBytes;
 
-    s->ssl_cert = NULL;
-    s->ssl_cert_len = 0;
-    s->ssl_cipher = NULL;
-    s->ssl_session = NULL;
-    s->ssl_key_size = -1;
-
-    s->headers_names = NULL;
-    s->headers_values = NULL;
-    s->num_headers = 0;
     s->uw_map = uw_map;
     /*
      * Add SSL IIS environment
@@ -2065,6 +2050,8 @@ static int init_ws_service(isapi_private_data_t * private_data,
                 num_of_vars++;
             }
         }
+        /* XXX: To make the isapi plugin more consistent with the other web servers */
+        /* we should also set s->ssl_cipher, s->ssl_session, and s->ssl_key_size. */
         if (num_of_vars) {
             unsigned int j;
 
@@ -2084,7 +2071,7 @@ static int init_ws_service(isapi_private_data_t * private_data,
             s->num_attributes = num_of_vars;
             if (ssl_env_values[4] && ssl_env_values[4][0] == '1') {
                 CERT_CONTEXT_EX cc;
-                cc.cbAllocated = sizeof(huge_buf);
+                cc.cbAllocated = MAX_PACKET_SIZE;
                 cc.CertContext.pbCertEncoded = (BYTE *) huge_buf;
                 cc.CertContext.cbCertEncoded = 0;
 
@@ -2113,7 +2100,7 @@ static int init_ws_service(isapi_private_data_t * private_data,
         }
     }
 
-    huge_buf_sz = sizeof(huge_buf);
+    huge_buf_sz = MAX_PACKET_SIZE;
     if (get_server_value(private_data->lpEcb,
                          "ALL_HTTP", huge_buf, huge_buf_sz)) {
         unsigned int cnt = 0;
@@ -2126,7 +2113,7 @@ static int init_ws_service(isapi_private_data_t * private_data,
         }
 
         if (cnt) {
-            char *headers_buf = jk_pool_strdup(&private_data->p, huge_buf);
+            char *headers_buf = huge_buf;
             unsigned int i;
             size_t len_of_http_prefix = strlen("HTTP_");
             BOOL need_content_length_header = (s->content_length == 0);
