@@ -1,8 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -16,7 +17,7 @@
 /*
  *
  * @author Mladen Turk
- * @version $Revision: 405933 $, $Date: 2006-05-12 18:13:44 -0500 (Fri, 12 May 2006) $
+ * @version $Revision: 523564 $, $Date: 2007-03-29 07:22:47 +0200 (Thu, 29 Mar 2007) $
  */
 
 #include "apr.h"
@@ -94,7 +95,7 @@ TCN_IMPLEMENT_CALL(jboolean, OS, is)(TCN_STDARGS, jint type)
     else if (type == 6)
         return JNI_TRUE;
 #endif
-#if defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
     else if (type == 7)
         return JNI_TRUE;
 #endif
