@@ -1,8 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -16,7 +17,7 @@
 /*
  *
  * @author Mladen Turk
- * @version $Revision: 440699 $, $Date: 2006-09-06 07:30:48 -0500 (Wed, 06 Sep 2006) $
+ * @version $Revision: 473703 $, $Date: 2006-11-11 05:30:52 -0700 (Sat, 11 Nov 2006) $
  */
 
 #include "tcn.h"
@@ -69,7 +70,7 @@ void tcn_ThrowMemoryException(JNIEnv *env, const char *file, int line, const cha
         if (f != file) {
             f++;
         }
-        sprintf(fmt, "%s for [%s::%04d]", msg, line, f);
+        sprintf(fmt, "%s for [%04d@%s]", msg, line, f);
         (*env)->ThrowNew(env, javaExceptionClass, &fmt[0]);
     }
     else
