@@ -46,7 +46,6 @@ public class InputBuffer extends Reader
 
     // -------------------------------------------------------------- Constants
 
-
     public static final String DEFAULT_ENCODING = 
         org.apache.coyote.Constants.DEFAULT_CHARACTER_ENCODING;
     public static final int DEFAULT_BUFFER_SIZE = 8*1024;
@@ -259,8 +258,8 @@ public class InputBuffer extends Reader
             return -1;
         if (coyoteRequest == null)
             return -1;
-
-        state = BYTE_STATE;
+        if(state == INITIAL_STATE)
+            state = BYTE_STATE;
 
         int result = coyoteRequest.doRead(bb);
 
@@ -293,6 +292,8 @@ public class InputBuffer extends Reader
     public void realWriteChars(char c[], int off, int len) 
         throws IOException {
         markPos = -1;
+        cb.setOffset(0);
+        cb.setEnd(0);
     }
 
 
@@ -318,13 +319,9 @@ public class InputBuffer extends Reader
             cb.setOffset(0);
             cb.setEnd(0);
         }
-
-        int limit = bb.getLength()+cb.getStart();
-        if( cb.getLimit() < limit ) 
-            cb.setLimit(limit);
-        conv.convert(bb, cb);
-        bb.setOffset(bb.getEnd());
         state = CHAR_STATE;
+        conv.convert(bb, cb, len);
+        bb.setOffset(bb.getEnd());
 
         return cb.getLength();
 
