@@ -58,7 +58,7 @@ import org.apache.tomcat.util.compat.JdkCompat;
  *
  * @author Remy Maucherat
  * @author Craig R. McClanahan
- * @version $Revision: 567009 $ $Date: 2007-08-17 04:54:37 -0600 (Fri, 17 Aug 2007) $
+ * @version $Revision: 609449 $ $Date: 2008-01-06 15:31:10 -0700 (Sun, 06 Jan 2008) $
  */
 
 public class Response
@@ -652,6 +652,9 @@ public class Response
 
         coyoteResponse.reset();
         outputBuffer.reset();
+        usingOutputStream = false;
+        usingWriter = false;
+        isCharacterEncodingSet = false;
     }
 
 
@@ -937,9 +940,9 @@ public class Response
         if (included)
             return;
 
-        cookies.add(cookie);
-
         final StringBuffer sb = new StringBuffer();
+        //web application code can receive a IllegalArgumentException 
+        //from the appendCookieValue invokation
         if (SecurityUtil.isPackageProtectionEnabled()) {
             AccessController.doPrivileged(new PrivilegedAction() {
                 public Object run(){
@@ -958,11 +961,13 @@ public class Response
                      cookie.getMaxAge(), cookie.getSecure());
         }
 
+        // if we reached here, no exception, cookie is valid
         // the header name is Set-Cookie for both "old" and v.1 ( RFC2109 )
         // RFC2965 is not supported by browsers and the Servlet spec
         // asks for 2109.
         addHeader("Set-Cookie", sb.toString());
 
+        cookies.add(cookie);
     }
 
 
