@@ -60,7 +60,7 @@ import org.apache.commons.logging.Log;
  * <code>javax.servlet.ServletResponseWrapper</code>.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 545175 $ $Date: 2007-06-07 15:31:16 +0200 (Thu, 07 Jun 2007) $
+ * @version $Revision: 572854 $ $Date: 2007-09-04 19:53:49 -0600 (Tue, 04 Sep 2007) $
  */
 
 final class ApplicationDispatcher
@@ -362,10 +362,6 @@ final class ApplicationDispatcher
             wrequest.setQueryString(hrequest.getQueryString());
 
             processRequest(request,response,state);
-
-            wrequest.recycle();
-            unwrapRequest(state);
-
         }
 
         // Handle an HTTP path-based forward
@@ -401,10 +397,6 @@ final class ApplicationDispatcher
             }
 
             processRequest(request,response,state);
-
-            wrequest.recycle();
-            unwrapRequest(state);
-
         }
 
         // This is not a real close in order to support error processing
@@ -554,8 +546,6 @@ final class ApplicationDispatcher
                     ApplicationFilterFactory.DISPATCHER_REQUEST_PATH_ATTR,
                     servletPath);
             invoke(state.outerRequest, state.outerResponse, state);
-
-            wrequest.recycle();
         }
 
         // Handle an HTTP path based include
@@ -592,8 +582,6 @@ final class ApplicationDispatcher
                     ApplicationFilterFactory.DISPATCHER_REQUEST_PATH_ATTR,
                     servletPath);
             invoke(state.outerRequest, state.outerResponse, state);
-
-            wrequest.recycle();
         }
 
     }
@@ -768,6 +756,8 @@ final class ApplicationDispatcher
         // See Bugzilla 30949
         unwrapRequest(state);
         unwrapResponse(state);
+        // Recycle request if necessary (also BZ 30949)
+        recycleRequestWrapper(state);
 
         // Rethrow an exception if one was thrown by the invoked servlet
         if (ioException != null)
@@ -1026,4 +1016,10 @@ final class ApplicationDispatcher
                     "applicationDispatcher.specViolation.response"));
         }
     }
+    
+    private void recycleRequestWrapper(State state) {
+        if (state.wrapRequest instanceof ApplicationHttpRequest) {
+            ((ApplicationHttpRequest) state.wrapRequest).recycle();
+        }
+    }
 }
