@@ -1,9 +1,10 @@
 /*
- * Copyright 1999,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -60,7 +61,7 @@ import org.apache.commons.modeler.Registry;
  * location) are identical to those currently supported by Tomcat 3.X.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 388949 $ $Date: 2006-03-26 13:55:03 -0600 (Sun, 26 Mar 2006) $
+ * @version $Revision: 522281 $ $Date: 2007-03-25 17:28:12 +0200 (Sun, 25 Mar 2007) $
  */
 
 public abstract class RealmBase
@@ -1324,10 +1325,19 @@ public abstract class RealmBase
     }
 
     protected boolean initialized=false;
-    
+
+    /**
+     * Initialize this Realm.  If it's already been
+     * initialized, do nothing.
+     */    
     public void init() {
-        this.containerLog = container.getLogger();
+        // Bugzilla 39875: if already initialized, do nothing
         if( initialized && container != null ) return;
+
+        // We want logger as soon as possible
+        if (container != null) {
+            this.containerLog = container.getLogger();
+        }
         
         initialized=true;
         if( container== null ) {
