@@ -1,9 +1,10 @@
 /*
- * Copyright 1999,2004-2006 The Apache Software Foundation.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *      http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -54,6 +55,7 @@ import javax.xml.transform.stream.StreamResult;
 import javax.xml.transform.stream.StreamSource;
 
 import org.apache.catalina.Globals;
+import org.apache.catalina.util.RequestUtil;
 import org.apache.catalina.util.ServerInfo;
 import org.apache.catalina.util.StringManager;
 import org.apache.catalina.util.URLEncoder;
@@ -69,7 +71,7 @@ import org.apache.naming.resources.ResourceAttributes;
  *
  * @author Craig R. McClanahan
  * @author Remy Maucherat
- * @version $Revision: 393784 $ $Date: 2006-04-13 06:19:06 -0500 (Thu, 13 Apr 2006) $
+ * @version $Revision: 543679 $ $Date: 2007-06-02 02:42:19 +0200 (Sat, 02 Jun 2007) $
  */
 
 public class DefaultServlet
@@ -218,46 +220,65 @@ public class DefaultServlet
         String value = null;
         try {
             value = getServletConfig().getInitParameter("debug");
-            debug = Integer.parseInt(value);
-        } catch (Throwable t) {
-            ;
+            if (value != null) {
+                debug = Integer.parseInt(value);
+            }
+        } catch (Exception e) {
+            log("DefaultServlet.init: couldn't read debug from " + value);
         }
+
         try {
             value = getServletConfig().getInitParameter("input");
-            input = Integer.parseInt(value);
-        } catch (Throwable t) {
-            ;
+            if (value != null) {
+                input = Integer.parseInt(value);
+            }
+        } catch (Exception e) {
+            log("DefaultServlet.init: couldn't read input from " + value);
         }
+
         try {
             value = getServletConfig().getInitParameter("listings");
-            listings = (new Boolean(value)).booleanValue();
-        } catch (Throwable t) {
-            ;
+            if (value != null) {
+                listings = (new Boolean(value)).booleanValue();
+            }
+        } catch (Exception e) {
+            log("DefaultServlet.init: couldn't read listings from " + value);
         }
+
         try {
             value = getServletConfig().getInitParameter("readonly");
-            if (value != null)
+            if (value != null) {
                 readOnly = (new Boolean(value)).booleanValue();
-        } catch (Throwable t) {
-            ;
+            }
+        } catch (Exception e) {
+            log("DefaultServlet.init: couldn't read readonly from " + value);
         }
+
         try {
             value = getServletConfig().getInitParameter("output");
-            output = Integer.parseInt(value);
-        } catch (Throwable t) {
-            ;
+            if (value != null) {
+                output = Integer.parseInt(value);
+            }
+        } catch (Exception e) {
+            log("DefaultServlet.init: couldn't read output from " + value);
         }
+
         try {
             value = getServletConfig().getInitParameter("sendfileSize");
-            sendfileSize = Integer.parseInt(value) * 1024;
-        } catch (Throwable t) {
-            ;
+            if (value != null) {
+                sendfileSize = Integer.parseInt(value) * 1024;
+            }
+        } catch (Exception e) {
+            log("DefaultServlet.init: couldn't read sendfileSize from " + value);
         }
+
         try {
             value = getServletConfig().getInitParameter("fileEncoding");
-            fileEncoding = value;
-        } catch (Throwable t) {
-            ;
+            if (value != null) {
+                fileEncoding = value;
+            }
+        } catch (Exception e) {
+            log("DefaultServlet.init: couldn't read fileEncoding from " + value);
         }
 
         globalXsltFile = getServletConfig().getInitParameter("globalXsltFile");
@@ -282,6 +303,7 @@ public class DefaultServlet
         } catch(ClassCastException e) {
             // Failed : Not the right type
         }
+
         if (resources == null) {
             try {
                 resources =
@@ -457,6 +479,15 @@ public class DefaultServlet
             result = false;
         }
 
+        // Bugzilla 40326: at this point content file should be safe to delete
+        // as it's no longer referenced.  Let's not rely on deleteOnExit because
+        // it's a memory leak, as noted in this Bugzilla issue.
+        try {
+            contentFile.delete();
+        } catch (Exception e) {
+            log("DefaultServlet.doPut: couldn't delete temporary file: " + e.getMessage());
+        }
+
         if (result) {
             if (exists) {
                 resp.setStatus(HttpServletResponse.SC_NO_CONTENT);
@@ -487,10 +518,7 @@ public class DefaultServlet
         // Convert all '/' characters to '.' in resourcePath
         String convertedResourcePath = path.replace('/', '.');
         File contentFile = new File(tempDir, convertedResourcePath);
-        if (contentFile.createNewFile()) {
-            // Clean up contentFile when Tomcat is terminated
-            contentFile.deleteOnExit();
-        }
+        contentFile.createNewFile();
 
         RandomAccessFile randAccessContentFile =
             new RandomAccessFile(contentFile, "rw");
@@ -501,6 +529,7 @@ public class DefaultServlet
             if (obj instanceof Resource)
                 oldResource = (Resource) obj;
         } catch (NamingException e) {
+            log("DefaultServlet.executePartialPut: couldn't find resource at " + path);
         }
 
         // Copy data in oldRevisionContent to contentFile
@@ -788,7 +817,8 @@ public class DefaultServlet
                 // If it fails, we try to get a Writer instead if we're
                 // trying to serve a text file
                 if ( (contentType == null)
-                     || (contentType.startsWith("text")) ) {
+                     || (contentType.startsWith("text"))
+                     || (contentType.endsWith("xml")) ) {
                     writer = response.getWriter();
                 } else {
                     throw e;
@@ -1205,7 +1235,7 @@ public class DefaultServlet
                   .append("'");
 
                 sb.append(">");
-                sb.append(trimmed);
+                sb.append(RequestUtil.filter(trimmed));
                 if (childCacheEntry.context != null)
                     sb.append("/");
                 sb.append("</entry>");
@@ -1374,7 +1404,7 @@ public class DefaultServlet
                 if (childCacheEntry.context != null)
                     sb.append("/");
                 sb.append("\"><tt>");
-                sb.append(trimmed);
+                sb.append(RequestUtil.filter(trimmed));
                 if (childCacheEntry.context != null)
                     sb.append("/");
                 sb.append("</tt></a></td>\r\n");
@@ -1454,10 +1484,10 @@ public class DefaultServlet
 
                     return buffer.toString();
                  }
-             } catch(Throwable e) {
-                 ; /* Should only be IOException or NamingException
-                    * can be ignored
-                    */
+             } catch(IOException ioe) {
+                 log("DefaultServlet.getReadme: IO exception: " + ioe.getMessage());
+             } catch (NamingException ne) {
+                 log("DefaultServlet.getReadme: Naming exception: " + ne.getMessage());
              }
         }
 
@@ -1478,10 +1508,10 @@ public class DefaultServlet
                     if (is!=null)
                         return is;
                 }
-             } catch(Throwable e) {
-                 ; /* Should only be IOException or NamingException
-                    * can be ignored
-                    */
+            } catch(IOException ioe) {
+                log("DefaultServlet.findXsltInputStream: IO exception: " + ioe.getMessage());
+            } catch (NamingException ne) {
+                log("DefaultServlet.findXsltInputStream: Naming exception: " + ne.getMessage());
              }
         }
 
@@ -1499,15 +1529,17 @@ public class DefaultServlet
                     fis.read(b);
                     return new ByteArrayInputStream(b);
                 }
-            } catch(Throwable e) {
-                log("This shouldn't happen (?)...", e);
+            } catch(Exception e) {
+                log("DefaultServlet.findXsltInputStream: can't read "
+                    + globalXsltFile);
                 return null;
             } finally {
                 try {
                     if (fis!=null)
                         fis.close();
-                } catch(Throwable e){
-                    ;
+                } catch(Exception e) {
+                    log("DefaultServlet.findXsltInputStream: "
+                        + " exception closing input stream: " + e.getMessage());
                 }
             }
         }
@@ -1617,10 +1649,12 @@ public class DefaultServlet
                 // If an If-None-Match header has been specified, if modified since
                 // is ignored.
                 if ((request.getHeader("If-None-Match") == null)
-                    && (lastModified <= headerValue + 1000)) {
+                    && (lastModified < headerValue + 1000)) {
                     // The entity has not been modified since the date
                     // specified by the client. This is not an error case.
                     response.setStatus(HttpServletResponse.SC_NOT_MODIFIED);
+                    response.setHeader("ETag", getETag(resourceAttributes));
+
                     return false;
                 }
             }
@@ -1677,6 +1711,8 @@ public class DefaultServlet
                 if ( ("GET".equals(request.getMethod()))
                      || ("HEAD".equals(request.getMethod())) ) {
                     response.setStatus(HttpServletResponse.SC_NOT_MODIFIED);
+                    response.setHeader("ETag", getETag(resourceAttributes));
+
                     return false;
                 } else {
                     response.sendError
@@ -1708,7 +1744,7 @@ public class DefaultServlet
             long lastModified = resourceAttributes.getLastModified();
             long headerValue = request.getDateHeader("If-Unmodified-Since");
             if (headerValue != -1) {
-                if ( lastModified > (headerValue + 1000)) {
+                if ( lastModified >= (headerValue + 1000)) {
                     // The entity has not been modified since the date
                     // specified by the client. This is not an error case.
                     response.sendError(HttpServletResponse.SC_PRECONDITION_FAILED);
@@ -1762,14 +1798,15 @@ public class DefaultServlet
         // Clean up the input stream
         try {
             istream.close();
-        } catch (Throwable t) {
-            ;
+        } catch (Exception e) {
+            log("DefaultServlet.copy: exception closing input stream: "
+                + e.getMessage());
         }
 
         // Rethrow any exception that has occurred
-        if (exception != null)
+        if (exception != null) {
             throw exception;
-
+        }
     }
 
 
@@ -1809,14 +1846,15 @@ public class DefaultServlet
         // Clean up the reader
         try {
             reader.close();
-        } catch (Throwable t) {
-            ;
+        } catch (Exception e) {
+            log("DefaultServlet.copy: exception closing reader: "
+                + e.getMessage());
         }
 
         // Rethrow any exception that has occurred
-        if (exception != null)
+        if (exception != null) {
             throw exception;
-
+        }
     }
 
 
@@ -1844,14 +1882,15 @@ public class DefaultServlet
         // Clean up the input stream
         try {
             istream.close();
-        } catch (Throwable t) {
-            ;
+        } catch (Exception e) {
+            log("DefaultServlet.copy: exception closing input stream: "
+                + e.getMessage());
         }
 
         // Rethrow any exception that has occurred
-        if (exception != null)
+        if (exception != null) {
             throw exception;
-
+        }
     }
 
 
@@ -1886,14 +1925,15 @@ public class DefaultServlet
         // Clean up the input stream
         try {
             reader.close();
-        } catch (Throwable t) {
-            ;
+        } catch (Exception e) {
+            log("DefaultServlet.copy: exception closing reader: "
+                + e.getMessage());
         }
 
         // Rethrow any exception that has occurred
-        if (exception != null)
+        if (exception != null) {
             throw exception;
-
+        }
     }
 
 
@@ -1938,8 +1978,9 @@ public class DefaultServlet
 
             try {
                 istream.close();
-            } catch (Throwable t) {
-                ;
+            } catch (Exception e) {
+                log("DefaultServlet.copy: exception closing input stream: "
+                    + e.getMessage());
             }
 
         }
@@ -1948,9 +1989,9 @@ public class DefaultServlet
         ostream.print("--" + mimeSeparation + "--");
 
         // Rethrow any exception that has occurred
-        if (exception != null)
+        if (exception != null) {
             throw exception;
-
+        }
     }
 
 
@@ -2001,8 +2042,9 @@ public class DefaultServlet
 
             try {
                 reader.close();
-            } catch (Throwable t) {
-                ;
+            } catch (Exception e) {
+                log("DefaultServlet.copy: exception closing reader: "
+                    + e.getMessage());
             }
 
         }
@@ -2011,9 +2053,9 @@ public class DefaultServlet
         writer.print("--" + mimeSeparation + "--");
 
         // Rethrow any exception that has occurred
-        if (exception != null)
+        if (exception != null) {
             throw exception;
-
+        }
     }
 
 
