@@ -58,7 +58,7 @@ import org.apache.commons.modeler.Registry;
  * be subclassed to create more sophisticated Manager implementations.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 531678 $ $Date: 2007-04-24 04:16:55 +0200 (Tue, 24 Apr 2007) $
+ * @version $Revision: 573959 $ $Date: 2007-09-09 02:41:35 -0600 (Sun, 09 Sep 2007) $
  */
 
 public abstract class ManagerBase implements Manager, MBeanRegistration {
@@ -1218,12 +1218,22 @@ public abstract class ManagerBase implements Manager, MBeanRegistration {
     public String getLastAccessedTime( String sessionId ) {
         Session s=(Session)sessions.get(sessionId);
         if( s==null ) {
-            log.info("Session not found " + sessionId);
+            if(log.isInfoEnabled())
+                log.info("Session not found " + sessionId);
             return "";
         }
         return new Date(s.getLastAccessedTime()).toString();
     }
 
+    public String getCreationTime( String sessionId ) {
+        Session s=(Session)sessions.get(sessionId);
+        if( s==null ) {
+            if(log.isInfoEnabled())
+                log.info("Session not found " + sessionId);
+            return "";
+        }
+        return new Date(s.getCreationTime()).toString();
+    }
 
     // -------------------- JMX and Registration  --------------------
     protected String domain;
