@@ -59,7 +59,7 @@ import org.apache.catalina.security.SecurityUtil;
  *
  * @author Craig R. McClanahan
  * @author Jean-Francois Arcand
- * @version $Revision: 479370 $ $Date: 2006-11-26 08:31:29 -0700 (Sun, 26 Nov 2006) $
+ * @version $Revision: 613527 $ $Date: 2008-01-20 02:58:17 -0700 (Sun, 20 Jan 2008) $
  */
 
 public class StandardManager
@@ -395,10 +395,10 @@ public class StandardManager
                     session.setManager(this);
                     sessions.put(session.getIdInternal(), session);
                     session.activate();
-                    session.endAccess();
+                    sessionCounter++;
                 }
             } catch (ClassNotFoundException e) {
-              log.error(sm.getString("standardManager.loading.cnfe", e), e);
+                log.error(sm.getString("standardManager.loading.cnfe", e), e);
                 if (ois != null) {
                     try {
                         ois.close();
@@ -409,7 +409,7 @@ public class StandardManager
                 }
                 throw e;
             } catch (IOException e) {
-              log.error(sm.getString("standardManager.loading.ioe", e), e);
+                log.error(sm.getString("standardManager.loading.ioe", e), e);
                 if (ois != null) {
                     try {
                         ois.close();
