@@ -1,9 +1,10 @@
 /*
- * Copyright 1999-2001,2004-2006 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -25,6 +26,8 @@ import java.io.InputStream;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.net.URL;
 import java.net.URLClassLoader;
 import java.util.ArrayList;
@@ -67,9 +70,6 @@ public final class TldConfig  {
     private static org.apache.commons.logging.Log log=
         org.apache.commons.logging.LogFactory.getLog( TldConfig.class );
 
-    private static final String FILE_URL_PREFIX = "file:";
-    private static final int FILE_URL_PREFIX_LEN = FILE_URL_PREFIX.length();
-
 
     /*
      * Initializes the set of JARs that are known not to contain any TLDs
@@ -687,7 +687,12 @@ public final class TldConfig  {
                     // This is definitely not as clean as using JAR URLs either
                     // over file or the custom jndi handler, but a lot less
                     // buggy overall
-                    File file = new File(urls[i].getFile());
+                    File file;
+                    try {
+                        file = new File(new URI(urls[i].toString()).getPath());
+                    } catch (URISyntaxException e1) {
+                        continue;
+                    }
                     try {
                         file = file.getCanonicalFile();
                     } catch (IOException e) {
