@@ -41,6 +41,7 @@ import org.apache.catalina.connector.Request;
 import org.apache.catalina.connector.Response;
 import org.apache.catalina.util.LifecycleSupport;
 import org.apache.catalina.util.StringManager;
+import org.apache.coyote.RequestInfo;
 
 
 /**
@@ -75,6 +76,7 @@ import org.apache.catalina.util.StringManager;
  * <li><b>%v</b> - Local server name
  * <li><b>%D</b> - Time taken to process the request, in millis
  * <li><b>%T</b> - Time taken to process the request, in seconds
+ * <li><b>%I</b> - current request thread name (can compare later with stacktraces)
  * </ul>
  * <p>In addition, the caller can specify one of the following aliases for
  * commonly utilized patterns:</p>
@@ -107,7 +109,7 @@ import org.apache.catalina.util.StringManager;
  * @author Craig R. McClanahan
  * @author Jason Brittain
  * @author Peter Rossbach
- * @version $Revision: 567009 $ $Date: 2007-08-17 04:54:37 -0600 (Fri, 17 Aug 2007) $
+ * @version $Revision: 613522 $ $Date: 2008-01-20 02:45:45 -0700 (Sun, 20 Jan 2008) $
  */
 
 public class AccessLogValve
@@ -118,6 +120,8 @@ public class AccessLogValve
     // ----------------------------------------------------------- Constructors
 
 
+    private static final String MARK_EMPTY = "-";
+
     /**
      * Construct a new instance of this class with default property values.
      */
@@ -150,7 +154,7 @@ public class AccessLogValve
      * The descriptive information about this implementation.
      */
     protected static final String info =
-        "org.apache.catalina.valves.AccessLogValve/1.0";
+        "org.apache.catalina.valves.AccessLogValve/1.1";
 
 
     /**
@@ -603,7 +607,7 @@ public class AccessLogValve
 
             long length = response.getContentCountLong() ;
             if (length <= 0)
-                value = "-";
+                value = MARK_EMPTY;
             else
                 value = "" + length;
             result.append(value);
@@ -615,7 +619,7 @@ public class AccessLogValve
                 if(referer != null)
                     result.append(referer);
                 else
-                    result.append("-");
+                    result.append(MARK_EMPTY);
                 result.append("\"");
 
                 result.append(space);
@@ -624,7 +628,7 @@ public class AccessLogValve
                 if(ua != null)
                     result.append(ua);
                 else
-                    result.append("-");
+                    result.append(MARK_EMPTY);
                 result.append("\"");
             }
 
@@ -808,7 +812,7 @@ public class AccessLogValve
         } else if (pattern == 'b') {
             long length = response.getContentCountLong() ;
             if (length <= 0)
-                value = "-";
+                value = MARK_EMPTY;
             else
                 value = "" + length;
         } else if (pattern == 'B') {
@@ -818,7 +822,7 @@ public class AccessLogValve
         } else if (pattern == 'H') {
             value = request.getProtocol();
         } else if (pattern == 'l') {
-            value = "-";
+            value = MARK_EMPTY;
         } else if (pattern == 'm') {
             if (request != null)
                 value = request.getMethod();
@@ -849,22 +853,21 @@ public class AccessLogValve
                 sb.append(space);
                 sb.append(request.getProtocol());
             } else {
-                sb.append("- - ");
-                sb.append(request.getProtocol());
+                sb.append("- - -");
             }
             value = sb.toString();
         } else if (pattern == 'S') {
             if (request != null)
                 if (request.getSession(false) != null)
                     value = request.getSessionInternal(false).getIdInternal();
-                else value = "-";
+                else value = MARK_EMPTY;
             else
-                value = "-";
+                value = MARK_EMPTY;
         } else if (pattern == 's') {
             if (response != null)
                 value = "" + response.getStatus();
             else
-                value = "-";
+                value = MARK_EMPTY;
         } else if (pattern == 't') {
             StringBuffer temp = new StringBuffer("[");
             temp.append(dayFormatter.format(date));             // Day
@@ -884,14 +887,21 @@ public class AccessLogValve
             if (request != null)
                 value = request.getRemoteUser();
             if (value == null)
-                value = "-";
+                value = MARK_EMPTY;
         } else if (pattern == 'U') {
             if (request != null)
                 value = request.getRequestURI();
             else
-                value = "-";
+                value = MARK_EMPTY;
         } else if (pattern == 'v') {
             value = request.getServerName();
+        } else if (pattern == 'I' ) {
+            RequestInfo info = request.getCoyoteRequest().getRequestProcessor();
+            if(info != null) {
+                value= info.getWorkerThreadName();
+            } else {
+                value = MARK_EMPTY;
+            }
         } else {
             value = "???" + pattern + "???";
         }
@@ -974,9 +984,9 @@ public class AccessLogValve
                 else
                     return value.toString();
             else
-               return "-";
+               return MARK_EMPTY;
         } catch(Throwable e) {
-            return "-";
+            return MARK_EMPTY;
         }
     }
 
@@ -1017,7 +1027,7 @@ public class AccessLogValve
     private String calculateTimeZoneOffset(long offset) {
         StringBuffer tz = new StringBuffer();
         if ((offset<0))  {
-            tz.append("-");
+            tz.append(MARK_EMPTY);
             offset = -offset;
         } else {
             tz.append("+");
