@@ -1,9 +1,10 @@
 /*
- * Copyright 1999-2005 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -54,7 +55,7 @@ import org.apache.catalina.util.StringManager;
  * @author Craig R. McClanahan
  * @author Jason Brittain
  * @author Remy Maucherat
- * @version $Revision: 304032 $ $Date: 2005-07-27 10:11:55 -0500 (Wed, 27 Jul 2005) $
+ * @version $Revision: 567009 $ $Date: 2007-08-17 04:54:37 -0600 (Fri, 17 Aug 2007) $
  */
 
 public final class FastCommonAccessLogValve
@@ -114,14 +115,6 @@ public final class FastCommonAccessLogValve
       "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
 
 
-    /**
-     * If the current log pattern is the same as the common access log
-     * format pattern, then we'll set this variable to true and log in
-     * a more optimal and hard-coded way.
-     */
-    private boolean common = false;
-
-
     /**
      * For the combined format (common, plus useragent and referer), we do
      * the same
@@ -251,12 +244,6 @@ public final class FastCommonAccessLogValve
     private boolean resolveHosts = false;
 
 
-    /**
-     * Instant when the log daily rotation was last checked.
-     */
-    private long rotationLastChecked = 0L;
-
-
     /**
      * Are we doing conditional logging. default false.
      */
@@ -536,8 +523,7 @@ public final class FastCommonAccessLogValve
         
         result.append(space);
         
-        int length = response.getContentCount();
-        
+        long length = response.getContentCountLong() ;
         if (length <= 0)
             value = "-";
         else
