@@ -1,9 +1,10 @@
 /*
- * Copyright 1999-2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -39,14 +40,22 @@ import org.apache.commons.logging.Log;
  * <p>This Valve may be attached to any Container, depending on the granularity
  * of the logging you wish to perform.</p>
  *
+ * <p>Note that this Valve sets the character encoding of the request to the default
+ * (ISO-8859-1) if it's the first thing invoking request.getParameterNames, which
+ * is usually the case.  If you're running in an environment where this encoding
+ * is problematic, consider using another debugging approach such as a Filter that
+ * reproduces this Valve's functionality.</p>
+ *
+ * <p>For a similar mechanism that is portable to all Servlet 2.4
+ * containers, check out the "RequestDumperFilter" Filter in the
+ * example application (the source for this filter may be found in
+ * $CATALINA_HOME/webapps/examples/WEB-INF/classes/filters.</p>
+ *
  * @author Craig R. McClanahan
- * @version $Revision: 303133 $ $Date: 2004-08-29 11:46:15 -0500 (Sun, 29 Aug 2004) $
+ * @version $Revision: 490487 $ $Date: 2006-12-27 05:26:07 -0700 (Wed, 27 Dec 2006) $
  */
 
-public class RequestDumperValve
-    extends ValveBase {
-
-
+public class RequestDumperValve extends ValveBase {
     // ----------------------------------------------------- Instance Variables
 
 
