@@ -1,9 +1,10 @@
 /*
- * Copyright 1999,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -43,6 +44,7 @@ import javax.servlet.http.HttpSessionEvent;
 import javax.servlet.http.HttpSessionListener;
 
 import org.apache.catalina.Context;
+import org.apache.catalina.Globals;
 import org.apache.catalina.Manager;
 import org.apache.catalina.Session;
 import org.apache.catalina.SessionEvent;
@@ -72,7 +74,7 @@ import org.apache.catalina.util.StringManager;
  * @author Craig R. McClanahan
  * @author Sean Legassick
  * @author <a href="mailto:jon@latchkey.com">Jon S. Stevens </a>
- * @version $Revision: 399358 $ $Date: 2006-05-03 12:16:15 -0500 (Wed, 03 May 2006) $
+ * @version $Revision: 525783 $ $Date: 2007-04-05 11:41:20 +0200 (Thu, 05 Apr 2007) $
  */
 
 public class DeltaSession implements HttpSession, Session, Serializable,
@@ -180,6 +182,12 @@ public class DeltaSession implements HttpSession, Session, Serializable,
      */
     private int maxInactiveInterval = -1;
 
+    /**
+     * The maxInactiveInterval + tolerance time interval, in seconds, between client requests before
+     * the servlet container may invalidate a backup session from other cluster node.
+     */
+    private int expireTolerance = 300;
+
     /**
      * Flag indicating whether this session is new or not.
      */
@@ -252,6 +260,8 @@ public class DeltaSession implements HttpSession, Session, Serializable,
      */
     protected transient int accessCount = 0;
 
+    private Object lock = new Object();
+
     // ----------------------------------------------------------- Constructors
     
     /**
@@ -408,9 +418,8 @@ public class DeltaSession implements HttpSession, Session, Serializable,
                         } catch (Exception e) {
                             ;
                         }
-                        // FIXME - should we do anything besides log these?
-                        log.error(sm.getString("standardSession.sessionEvent"),
-                                t);
+                        manager.getContainer().getLogger().error
+                           (sm.getString("standardSession.sessionEvent"), t);
                     }
                 }
             }
@@ -606,7 +615,7 @@ public class DeltaSession implements HttpSession, Session, Serializable,
                     expire(true);
                 }
             } else {
-                if (timeIdle >= (2 * maxInactiveInterval)) {
+                if (timeIdle >= (maxInactiveInterval+expireTolerance)) {
                 //if the session has been idle twice as long as allowed,
                 //the primary session has probably crashed, and no other
                 //requests are coming in. that is why we do this. otherwise
@@ -644,12 +653,20 @@ public class DeltaSession implements HttpSession, Session, Serializable,
 
         evaluateIfValid();
 
-        accessCount++;
+        if (Globals.STRICT_SERVLET_COMPLIANCE) {
+            synchronized (lock) {
+                accessCount++;
+            }
+        }
     }
 
     public void endAccess() {
         isNew = false;
-        accessCount--;
+        if (Globals.STRICT_SERVLET_COMPLIANCE) {
+            synchronized (lock) {
+                accessCount--;
+            }
+        }
         if(manager instanceof DeltaManager)
             ((DeltaManager)manager).registerSessionAtReplicationValve(this);
     }
@@ -726,15 +743,14 @@ public class DeltaSession implements HttpSession, Session, Serializable,
                             } catch (Exception e) {
                                 ;
                             }
-                            // FIXME - should we do anything besides log these?
-                            log.error(sm
+                            manager.getContainer().getLogger().error(sm
                                     .getString("standardSession.sessionEvent"),
                                     t);
                         }
                     }
                 }
-            }//end if
-            //end fix
+            }
+
             accessCount = 0;
             setValid(false);
 
@@ -1254,7 +1270,8 @@ public class DeltaSession implements HttpSession, Session, Serializable,
                 try {
                     ((HttpSessionBindingListener) value).valueBound(event);
                 } catch (Exception x) {
-                    log.error(smp.getString("deltaSession.valueBound.ex"), x);
+                    manager.getContainer().getLogger().error
+                        (smp.getString("deltaSession.valueBound.ex"), x);
                 }
             }
         }
@@ -1269,7 +1286,8 @@ public class DeltaSession implements HttpSession, Session, Serializable,
                         .valueUnbound(new HttpSessionBindingEvent(
                                 (HttpSession) getSession(), name));
             } catch (Exception x) {
-                log.error(smp.getString("deltaSession.valueBinding.ex"), x);
+                manager.getContainer().getLogger().error
+                    (smp.getString("deltaSession.valueBinding.ex"), x);
             }
 
         }
@@ -1280,7 +1298,6 @@ public class DeltaSession implements HttpSession, Session, Serializable,
 
         // Notify interested application event listeners
         Context context = (Context) manager.getContainer();
-        //fix for standalone manager without container
         if (context != null) {
             Object listeners[] = context.getApplicationEventListeners();
             if (listeners == null)
@@ -1323,16 +1340,11 @@ public class DeltaSession implements HttpSession, Session, Serializable,
                     } catch (Exception e) {
                         ;
                     }
-                    // FIXME - should we do anything besides log these?
-                    log
-                            .error(
-                                    sm
-                                            .getString("standardSession.attributeEvent"),
-                                    t);
+                    manager.getContainer().getLogger().error
+                        (sm.getString("standardSession.attributeEvent"),t);
                 }
-            } //for
-        }//end if
-        //end fix
+            }
+        }
 
     }
 
@@ -1373,8 +1385,9 @@ public class DeltaSession implements HttpSession, Session, Serializable,
 
         //        setId((String) stream.readObject());
         id = (String) stream.readObject();
-        if (log.isDebugEnabled())
-            log.debug(smp.getString("deltaSession.readSession",  id));
+        org.apache.commons.logging.Log managerLog = manager.getContainer().getLogger() ;
+        if (managerLog.isDebugEnabled())
+            managerLog.debug(smp.getString("deltaSession.readSession",  id));
 
         // Deserialize the attribute count and attribute values
         if (attributes == null)
@@ -1387,6 +1400,9 @@ public class DeltaSession implements HttpSession, Session, Serializable,
             Object value = (Object) stream.readObject();
             if ((value instanceof String) && (value.equals(NOT_SERIALIZED)))
                 continue;
+            if (managerLog.isDebugEnabled())
+                managerLog.debug("  loading attribute '" + name +
+                    "' with value '" + value + "'");
             attributes.put(name, value);
         }
         isValid = isValidSave;
@@ -1437,8 +1453,9 @@ public class DeltaSession implements HttpSession, Session, Serializable,
         }
 
         stream.writeObject(id);
-        if (log.isDebugEnabled())
-            log.debug(smp.getString("deltaSession.writeSession",id));
+        org.apache.commons.logging.Log managerLog = manager.getContainer().getLogger() ;
+        if (managerLog.isDebugEnabled())
+            managerLog.debug(smp.getString("deltaSession.writeSession",id));
 
         // Accumulate the names of serializable and non-serializable attributes
         String keys[] = keys();
@@ -1462,15 +1479,18 @@ public class DeltaSession implements HttpSession, Session, Serializable,
             stream.writeObject((String) saveNames.get(i));
             try {
                 stream.writeObject(saveValues.get(i));
-                //                if (log.isDebugEnabled())
-                //                    log.debug(" storing attribute '" + saveNames.get(i) +
-                //                        "' with value '" + saveValues.get(i) + "'");
+                if (managerLog.isDebugEnabled()) {
+                    managerLog.debug(" storing attribute '" + saveNames.get(i) +
+                        "' with value '" + saveValues.get(i) + "'");
+                }
             } catch (NotSerializableException e) {
-                log.error(sm.getString("standardSession.notSerializable",
+                managerLog.warn(sm.getString("standardSession.notSerializable",
                         saveNames.get(i), id), e);
                 stream.writeObject(NOT_SERIALIZED);
-                log.error("  storing attribute '" + saveNames.get(i)
+                if(managerLog.isDebugEnabled()) {
+                    managerLog.debug("  storing attribute '" + saveNames.get(i)
                         + "' with value NOT_SERIALIZED");
+                }
             }
         }
 
@@ -1588,12 +1608,12 @@ public class DeltaSession implements HttpSession, Session, Serializable,
             try {
                 ((HttpSessionBindingListener) value).valueUnbound(event);
             } catch (Exception x) {
-                log.error(smp.getString("deltaSession.valueUnbound.ex"), x);
+                manager.getContainer().getLogger().error
+                    (smp.getString("deltaSession.valueUnbound.ex"), x);
             }
         }
         // Notify interested application event listeners
         Context context = (Context) manager.getContainer();
-        //fix for standalone manager without container
         if (context != null) {
             Object listeners[] = context.getApplicationEventListeners();
             if (listeners == null)
@@ -1619,16 +1639,11 @@ public class DeltaSession implements HttpSession, Session, Serializable,
                     } catch (Exception e) {
                         ;
                     }
-                    // FIXME - should we do anything besides log these?
-                    log
-                            .error(
-                                    sm
-                                            .getString("standardSession.attributeEvent"),
-                                    t);
+                    manager.getContainer().getLogger().error
+                        (sm.getString("standardSession.attributeEvent"),t);
                 }
-            } //for
-        }//end if
-        //end fix
+            }
+        }
 
     }
 
@@ -1648,6 +1663,14 @@ public class DeltaSession implements HttpSession, Session, Serializable,
         return accessCount;
     }
 
+    protected void setExpireTolerance(int expireTolerance) {
+        this.expireTolerance = expireTolerance;
+      }
+    
+    protected int getExpireTolerance() {
+        return expireTolerance;
+    }
+
 }
 
 // -------------------------------------------------------------- Private Class
