@@ -1,9 +1,10 @@
 /*
- * Copyright 1999,2004-2005 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -80,7 +81,7 @@ import org.apache.catalina.valves.ValveBase;
  * This use case means that only requested session are migrated.
  * 
  * @author Peter Rossbach
- * @version $Revision: 393256 $ $Date: 2006-04-11 11:20:28 -0500 (Tue, 11 Apr 2006) $
+ * @version $Revision: 565470 $ $Date: 2007-08-13 12:35:13 -0600 (Mon, 13 Aug 2007) $
  */
 public class JvmRouteBinderValve extends ValveBase implements ClusterValve, Lifecycle {
 
@@ -217,9 +218,12 @@ public class JvmRouteBinderValve extends ValveBase implements ClusterValve, Life
      * @param response current response
      */
     protected void handlePossibleTurnover(Request request, Response response) {
-        Session session = request.getSessionInternal(false);
+        Session session = request.getSessionInternal(false);       
         if (session != null) {
-            long t1 = System.currentTimeMillis();
+            long t1 = 0 ;
+            if (log.isDebugEnabled()) {
+                t1 = System.currentTimeMillis();
+            }
             String jvmRoute = getLocalJvmRoute(request);
             if (jvmRoute == null) {
                 if (log.isWarnEnabled())
