@@ -1,9 +1,10 @@
 /*
- * Copyright 1999,2004-2005 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -33,7 +34,7 @@ import org.apache.catalina.cluster.io.ObjectReader;
 * FIXME jmx support
 * @author Peter Rossbach
 * @author Filip Hanik
-* @version $Revision: 380229 $ $Date: 2006-02-23 15:28:29 -0600 (Thu, 23 Feb 2006) $
+* @version $Revision: 567298 $ $Date: 2007-08-18 11:14:07 -0600 (Sat, 18 Aug 2007) $
 */
 public class ReplicationListener extends ClusterReceiverBase
 {
@@ -122,6 +123,7 @@ public class ReplicationListener extends ClusterReceiverBase
         serverChannel.configureBlocking (false);
         // register the ServerSocketChannel with the Selector
         serverChannel.register (selector, SelectionKey.OP_ACCEPT);
+        
         while (doListen && selector != null) {
             // this may block for a long time, upon return the
             // selected set contains keys of the ready channels
@@ -134,11 +136,11 @@ public class ReplicationListener extends ClusterReceiverBase
                     //selector wakeup().
                     //if that happens, we must ensure that that
                     //thread has enough time to call interestOps
-                    synchronized (interestOpsMutex) {
+                    //synchronized (interestOpsMutex) {
                         //if we got the lock, means there are no
                         //keys trying to register for the 
                         //interestOps method
-                    }
+                    //}
                     continue; // nothing to do
                 }
                 // get an iterator over the set of selected keys
@@ -150,7 +152,19 @@ public class ReplicationListener extends ClusterReceiverBase
                     if (key.isAcceptable()) {
                         ServerSocketChannel server =
                             (ServerSocketChannel) key.channel();
+                        // get channel
                         SocketChannel channel = server.accept();
+                        channel.socket().setReceiveBufferSize(getRxBufSize());
+                        channel.socket().setSendBufferSize(getTxBufSize());
+                        channel.socket().setTcpNoDelay(isTcpNoDelay());
+                        channel.socket().setKeepAlive(isSoKeepAlive());
+                        channel.socket().setOOBInline(isOoBInline());
+                        channel.socket().setReuseAddress(isSoReuseAddress());
+                        channel.socket().setSoLinger(isSoLingerOn(),getSoLingerTime());
+                        channel.socket().setTrafficClass(getSoTrafficClass());
+                        if(getTimeout() > -1)
+                            channel.socket().setSoTimeout(getTimeout());
+                        // attach Reader and register channel
                         Object attach = new ObjectReader(channel, selector,
                                     this) ;
                         registerChannel(selector,
