@@ -1,9 +1,10 @@
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -19,11 +20,9 @@ package org.apache.webapp.admin;
 
 
 import java.io.IOException;
-import java.net.URLEncoder;
 import java.util.ArrayList;
 import javax.servlet.jsp.JspException;
 import javax.servlet.jsp.JspWriter;
-import javax.servlet.jsp.PageContext;
 import javax.servlet.jsp.tagext.BodyTagSupport;
 
 
@@ -44,7 +43,7 @@ import javax.servlet.jsp.tagext.BodyTagSupport;
  * <strong>FIXME</strong> - Internationalize the exception messages!
  *
  * @author Manveen Kaur
- * @version $Revision: 302726 $ $Date: 2004-02-27 08:59:07 -0600 (Fri, 27 Feb 2004) $
+ * @version $Revision: 479043 $ $Date: 2006-11-24 16:03:05 -0700 (Fri, 24 Nov 2006) $
  */
 
 public class TableTag extends BodyTagSupport {
@@ -155,7 +154,7 @@ public class TableTag extends BodyTagSupport {
         this.dataStyles.clear();
         this.styleIds.clear();
         
-        return (EVAL_BODY_TAG);
+        return (EVAL_BODY_BUFFERED);
  
      }    
 
