@@ -1,9 +1,10 @@
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -18,17 +19,18 @@
 package org.apache.webapp.admin.host;
 
 import javax.servlet.http.HttpServletRequest;
-import org.apache.struts.action.ActionError;
 import org.apache.struts.action.ActionErrors;
 import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
+import org.apache.struts.action.ActionMessage;
+
 import java.util.List;
 
 /**
  * Form bean for the alias page.
  *
  * @author Manveen Kaur
- * @version $Revision: 302726 $ $Date: 2004-02-27 08:59:07 -0600 (Fri, 27 Feb 2004) $
+ * @version $Revision: 479035 $ $Date: 2006-11-24 16:00:53 -0700 (Fri, 24 Nov 2006) $
  */
 
 public final class AliasForm extends ActionForm {
@@ -149,17 +151,13 @@ public final class AliasForm extends ActionForm {
         
         ActionErrors errors = new ActionErrors();
         
-        String submit = request.getParameter("submit");
-        
         // front end validation when save is clicked.
-        //if (submit != null) {
-            
-            // aliasName cannot be null
-            if ((aliasName== null) || (aliasName.length() < 1)) {
-                errors.add("aliasName", new ActionError("error.aliasName.required"));
-            }
+        // aliasName cannot be null
+        if ((aliasName== null) || (aliasName.length() < 1)) {
+            errors.add("aliasName",
+                    new ActionMessage("error.aliasName.required"));
+        }
                         
-        //}        
         return errors;       
     }
     
