@@ -1,9 +1,10 @@
 /*
- * Copyright 2002,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -18,15 +19,9 @@
 package org.apache.webapp.admin.realm;
 
 import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.Locale;
-import java.util.Set;
-import java.util.TreeSet;
 import javax.management.MBeanServer;
 import javax.management.ObjectName;
-import javax.management.ObjectInstance;
-import javax.management.modelmbean.ModelMBean;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpSession;
 import javax.servlet.http.HttpServletRequest;
@@ -48,7 +43,7 @@ import org.apache.webapp.admin.TreeControlNode;
  * transactions.
  *
  * @author Manveen Kaur
- * @version $Revision: 303390 $ $Date: 2004-10-18 01:37:56 -0500 (Mon, 18 Oct 2004) $
+ * @version $Revision: 479037 $ $Date: 2006-11-24 16:01:05 -0700 (Fri, 24 Nov 2006) $
  */
 
 public class DeleteRealmsAction extends Action {
@@ -121,7 +116,6 @@ public class DeleteRealmsAction extends Action {
                 if (control != null) {
                     control.selectNode(null);
                     TreeControlNode node = control.findNode(realms[i]);
-                    String domain = node.getDomain();
                     ObjectName fname = 
                         TomcatTreeBuilder.getMBeanFactory();
                     mBServer.invoke(fname, operation,
