@@ -1,9 +1,10 @@
 /*
- * Copyright 2002,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -16,21 +17,16 @@
 
 package org.apache.webapp.admin.resources;
 
-import java.util.List;
-import java.util.ArrayList;
-
 import javax.servlet.http.HttpServletRequest;
-import org.apache.struts.action.ActionError;
 import org.apache.struts.action.ActionErrors;
-import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
-import org.apache.webapp.admin.LabelValueBean;
+import org.apache.struts.action.ActionMessage;
 
 /**
  * Form bean for the individual data source page.
  *
  * @author Manveen Kaur
- * @version $Revision: 302726 $ $Date: 2004-02-27 08:59:07 -0600 (Fri, 27 Feb 2004) $
+ * @version $Revision: 479038 $ $Date: 2006-11-24 16:01:21 -0700 (Fri, 24 Nov 2006) $
  * @since 4.1
  */
 
@@ -295,58 +291,41 @@ public final class DataSourceForm extends BaseForm {
 
         errors = new ActionErrors();
 
-        String submit = request.getParameter("submit");
+        // url is a required field
+        if ((url == null) || (url.length() < 1)) {
+            errors.add("url",
+                       new ActionMessage("resources.error.url.required"));
+        }
 
-        //if (submit != null) {
+        // jndiName is a required field
+        if (( jndiName == null) || (jndiName.length() < 1)) {
+            errors.add("jndiName",
+                       new ActionMessage("resources.error.jndiName.required"));
+        }
 
-            // url is a required field
-            if ((url == null) || (url.length() < 1)) {
-                errors.add("url",
-                           new ActionError("resources.error.url.required"));
-            }
+        // driverClass is a required field
+        if ((driverClass == null) || (driverClass.length() < 1)) {
+            errors.add("driverClass",
+                       new ActionMessage("resources.error.driverClass.required"));
+        }
+        
+        // FIX ME -- need to do a range check
+        numberCheck("active", active , false, 0, 10000);
+        numberCheck("idle", idle , false, 0, 10000);
+        numberCheck("wait", wait , false, 0, 10000);
 
-            // jndiName is a required field
-            if (( jndiName == null) || (jndiName.length() < 1)) {
-                errors.add("jndiName",
-                           new ActionError("resources.error.jndiName.required"));
-            }
+        // Quotes not allowed in username
+        if ((username != null) && (username.indexOf('"') >= 0)) {
+            errors.add("username",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // driverClass is a required field
-            if ((driverClass == null) || (driverClass.length() < 1)) {
-                errors.add("driverClass",
-                           new ActionError("resources.error.driverClass.required"));
-            }
-            
-            // username is a required field
-            if ((username == null) || (username.length() < 1)) {
-                errors.add("username",
-                           new ActionError("users.error.username.required"));
-            }
-            
-            // commented out password can be an empty string
-            // password is a required field
-            //if ((password == null) || (password.length() < 1)) {
-            //    errors.add("password",
-            //               new ActionError("error.userPassword.required"));
-            //
-            
-            // FIX ME -- need to do a range check
-            numberCheck("active", active , false, 0, 10000);
-            numberCheck("idle", idle , false, 0, 10000);
-            numberCheck("wait", wait , false, 0, 10000);
+        // Quotes not allowed in password
+        if ((password != null) && (password.indexOf('"') > 0)) {
+            errors.add("password",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // Quotes not allowed in username
-            if ((username != null) && (username.indexOf('"') >= 0)) {
-                errors.add("username",
-                           new ActionError("users.error.quotes"));
-            }
-
-            // Quotes not allowed in password
-            if ((password != null) && (password.indexOf('"') > 0)) {
-                errors.add("password",
-                           new ActionError("users.error.quotes"));
-            }
-         //}
         return (errors);
     }
  
@@ -368,7 +347,7 @@ public final class DataSourceForm extends BaseForm {
         
         // Check for 'is required'
         if ((numText == null) || (numText.length() < 1)) {
-            errors.add(field, new ActionError("resources.error."+field+".required"));
+            errors.add(field, new ActionMessage("resources.error."+field+".required"));
         } else {
             
             // check for 'must be a number' in the 'valid range'
@@ -378,11 +357,11 @@ public final class DataSourceForm extends BaseForm {
                 if (rangeCheck) {
                     if ((num < min) || (num > max ))
                         errors.add( field,
-                        new ActionError("resources.error."+ field +".range"));
+                        new ActionMessage("resources.error."+ field +".range"));
                 }
             } catch (NumberFormatException e) {
                 errors.add(field,
-                new ActionError("resources.integer.error"));
+                new ActionMessage("resources.integer.error"));
             }
         }
     }
