@@ -1,9 +1,10 @@
 /*
- * Copyright 2002,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -17,7 +18,6 @@
 
 package org.apache.webapp.admin.resources;
 
-import java.util.Arrays;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.Collections;
@@ -34,7 +34,7 @@ import javax.management.ObjectInstance;
  *
  * @author Manveen Kaur
  * @author Amy Roh
- * @version $Revision: 302868 $ $Date: 2004-04-30 12:53:59 -0500 (Fri, 30 Apr 2004) $
+ * @version $Revision: 479038 $ $Date: 2006-11-24 16:01:21 -0700 (Fri, 24 Nov 2006) $
  * @since 4.1
  */
 
@@ -102,7 +102,6 @@ public class ResourceUtils {
         throws Exception {
                            
         ObjectName ename = null;
-        StringBuffer sb = null;        
         if (resourcetype!=null) {
             if (resourcetype.equals("Global")) {
                 ename = new ObjectName( domain + ENVIRONMENT_TYPE + 
