@@ -1,9 +1,10 @@
 /*
- * Copyright 2002,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -16,23 +17,16 @@
 
 package org.apache.webapp.admin.resources;
 
-import java.util.List;
-import java.util.ArrayList;
-
 import javax.servlet.http.HttpServletRequest;
-import org.apache.struts.action.ActionError;
 import org.apache.struts.action.ActionErrors;
-import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
-import org.apache.webapp.admin.LabelValueBean;
-
-import java.lang.reflect.Constructor;
+import org.apache.struts.action.ActionMessage;
 
 /**
  * Form bean for the individual user database page.
  *
  * @author Manveen Kaur
- * @version $Revision: 302726 $ $Date: 2004-02-27 08:59:07 -0600 (Fri, 27 Feb 2004) $
+ * @version $Revision: 479038 $ $Date: 2006-11-24 16:01:21 -0700 (Fri, 24 Nov 2006) $
  * @since 4.1
  */
 
@@ -165,39 +159,36 @@ public final class UserDatabaseForm extends BaseForm {
 
         errors = new ActionErrors();
 
-        String submit = request.getParameter("submit");
-        //if (submit != null) {
+        // name is a required field
+        if ((name == null) || (name.length() < 1)) {
+            errors.add("name",
+                       new ActionMessage("resources.error.name.required"));
+        }
 
-            // name is a required field
-            if ((name == null) || (name.length() < 1)) {
-                errors.add("name",
-                           new ActionError("resources.error.name.required"));
-            }
+        // path is a required field
+        if ((path == null) || (path.length() < 1)) {
+            errors.add("path",
+                       new ActionMessage("resources.error.path.required"));
+        }
 
-            // path is a required field
-            if ((path == null) || (path.length() < 1)) {
-                errors.add("path",
-                           new ActionError("resources.error.path.required"));
-            }
+        // Quotes not allowed in name
+        if ((name != null) && (name.indexOf('"') >= 0)) {
+            errors.add("name",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // Quotes not allowed in name
-            if ((name != null) && (name.indexOf('"') >= 0)) {
-                errors.add("name",
-                           new ActionError("users.error.quotes"));
-            }
+        // Quotes not allowed in path
+        if ((path != null) && (path.indexOf('"') > 0)) {
+            errors.add("path",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // Quotes not allowed in path
-            if ((path != null) && (path.indexOf('"') > 0)) {
-                errors.add("path",
-                           new ActionError("users.error.quotes"));
-            }
+        // Quotes not allowed in description
+        if ((description != null) && (description.indexOf('"') > 0)) {
+            errors.add("description",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // Quotes not allowed in description
-            if ((description != null) && (description.indexOf('"') > 0)) {
-                errors.add("description",
-                           new ActionError("users.error.quotes"));
-            }
-        //}
         return (errors);
     }
     
