@@ -1,9 +1,10 @@
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -18,17 +19,18 @@
 package org.apache.webapp.admin.service;
 
 import javax.servlet.http.HttpServletRequest;
-import org.apache.struts.action.ActionError;
 import org.apache.struts.action.ActionErrors;
 import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
+import org.apache.struts.action.ActionMessage;
+
 import java.util.List;
 
 /**
  * Form bean for the service page.
  *
  * @author Manveen Kaur
- * @version $Revision: 302986 $ $Date: 2004-06-27 21:14:52 -0500 (Sun, 27 Jun 2004) $
+ * @version $Revision: 479039 $ $Date: 2006-11-24 16:01:49 -0700 (Fri, 24 Nov 2006) $
  */
 
 public final class ServiceForm extends ActionForm {
@@ -341,22 +343,17 @@ public final class ServiceForm extends ActionForm {
     HttpServletRequest request) {
         
         ActionErrors errors = new ActionErrors();
-        String submit = request.getParameter("submit");
-        
-        //if (submit != null) {
 
-            if ((serviceName == null) || (serviceName.length() < 1)) {
-                errors.add("serviceName",
-                           new ActionError("error.serviceName.required"));
-            }
-            
-            if ((engineName == null) || (engineName.length() < 1)) {
-                errors.add("engineName",
-                           new ActionError("error.engineName.required"));
-            }
-
-        //}
+        if ((serviceName == null) || (serviceName.length() < 1)) {
+            errors.add("serviceName",
+                       new ActionMessage("error.serviceName.required"));
+        }
         
+        if ((engineName == null) || (engineName.length() < 1)) {
+            errors.add("engineName",
+                       new ActionMessage("error.engineName.required"));
+        }
+
         return errors;
     }
     
