@@ -1,9 +1,10 @@
 /*
- * Copyright 2002,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -19,10 +20,9 @@ package org.apache.webapp.admin.users;
 import java.net.URLDecoder;
 import javax.management.MBeanServer;
 import javax.servlet.http.HttpServletRequest;
-import org.apache.struts.action.ActionError;
 import org.apache.struts.action.ActionErrors;
-import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
+import org.apache.struts.action.ActionMessage;
 import org.apache.webapp.admin.ApplicationServlet;
 import org.apache.webapp.admin.TomcatTreeBuilder;
 
@@ -30,7 +30,7 @@ import org.apache.webapp.admin.TomcatTreeBuilder;
  * Form bean for the individual group page.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 303390 $ $Date: 2004-10-18 01:37:56 -0500 (Mon, 18 Oct 2004) $
+ * @version $Revision: 479041 $ $Date: 2006-11-24 16:02:20 -0700 (Fri, 24 Nov 2006) $
  * @since 4.1
  */
 
@@ -143,28 +143,23 @@ public final class GroupForm extends BaseForm {
         
         ActionErrors errors = new ActionErrors();
 
-        String submit = request.getParameter("submit");
-        //if (submit != null) {
+        // groupname is a required field
+        if ((groupname == null) || (groupname.length() < 1)) {
+            errors.add("groupname",
+                       new ActionMessage("users.error.groupname.required"));
+        }
 
-            // groupname is a required field
-            if ((groupname == null) || (groupname.length() < 1)) {
-                errors.add("groupname",
-                           new ActionError("users.error.groupname.required"));
-            }
+        // Quotes not allowed in groupname
+        if ((groupname != null) && (groupname.indexOf('"') >= 0)) {
+            errors.add("groupname",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // Quotes not allowed in groupname
-            if ((groupname != null) && (groupname.indexOf('"') >= 0)) {
-                errors.add("groupname",
-                           new ActionError("users.error.quotes"));
-            }
-
-            // Quotes not allowed in description
-            if ((description != null) && (description.indexOf('"') > 0)) {
-                errors.add("description",
-                           new ActionError("users.error.quotes"));
-            }
-
-        //}
+        // Quotes not allowed in description
+        if ((description != null) && (description.indexOf('"') > 0)) {
+            errors.add("description",
+                       new ActionMessage("users.error.quotes"));
+        }
 
         return (errors);
 
