@@ -1,9 +1,10 @@
 /*
- * Copyright 2002,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -20,10 +21,9 @@ package org.apache.webapp.admin.users;
 import java.net.URLDecoder;
 import javax.management.MBeanServer;
 import javax.servlet.http.HttpServletRequest;
-import org.apache.struts.action.ActionError;
 import org.apache.struts.action.ActionErrors;
-import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
+import org.apache.struts.action.ActionMessage;
 import org.apache.webapp.admin.ApplicationServlet;
 import org.apache.webapp.admin.TomcatTreeBuilder;
 
@@ -31,7 +31,7 @@ import org.apache.webapp.admin.TomcatTreeBuilder;
  * Form bean for the individual user page.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 303390 $ $Date: 2004-10-18 01:37:56 -0500 (Mon, 18 Oct 2004) $
+ * @version $Revision: 479041 $ $Date: 2006-11-24 16:02:20 -0700 (Fri, 24 Nov 2006) $
  * @since 4.1
  */
 
@@ -177,40 +177,35 @@ public final class UserForm extends BaseForm {
         
         ActionErrors errors = new ActionErrors();
 
-        String submit = request.getParameter("submit");
-        //if (submit != null) {
+        // username is a required field
+        if ((username == null) || (username.length() < 1)) {
+            errors.add("username",
+                       new ActionMessage("users.error.username.required"));
+        }
 
-            // username is a required field
-            if ((username == null) || (username.length() < 1)) {
-                errors.add("username",
-                           new ActionError("users.error.username.required"));
-            }
+        // uassword is a required field
+        if ((password == null) || (username.length() < 1)) {
+            errors.add("password",
+                       new ActionMessage("users.error.password.required"));
+        }
 
-            // uassword is a required field
-            if ((password == null) || (username.length() < 1)) {
-                errors.add("password",
-                           new ActionError("users.error.password.required"));
-            }
+        // Quotes not allowed in username
+        if ((username != null) && (username.indexOf('"') >= 0)) {
+            errors.add("username",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // Quotes not allowed in username
-            if ((username != null) && (username.indexOf('"') >= 0)) {
-                errors.add("username",
-                           new ActionError("users.error.quotes"));
-            }
+        // Quotes not allowed in password
+        if ((password != null) && (password.indexOf('"') > 0)) {
+            errors.add("description",
+                       new ActionMessage("users.error.quotes"));
+        }
 
-            // Quotes not allowed in password
-            if ((password != null) && (password.indexOf('"') > 0)) {
-                errors.add("description",
-                           new ActionError("users.error.quotes"));
-            }
-
-            // Quotes not allowed in fullName
-            if ((fullName != null) && (fullName.indexOf('"') > 0)) {
-                errors.add("fullName",
-                           new ActionError("users.error.quotes"));
-            }
-
-        //}
+        // Quotes not allowed in fullName
+        if ((fullName != null) && (fullName.indexOf('"') > 0)) {
+            errors.add("fullName",
+                       new ActionMessage("users.error.quotes"));
+        }
 
         return (errors);
 
