@@ -1,9 +1,10 @@
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -17,17 +18,17 @@
 package org.apache.webapp.admin.valve;
 
 import javax.servlet.http.HttpServletRequest;
-import org.apache.struts.action.ActionError;
 import org.apache.struts.action.ActionErrors;
-import org.apache.struts.action.ActionForm;
 import org.apache.struts.action.ActionMapping;
+import org.apache.struts.action.ActionMessage;
+
 import java.util.List;
 
 /**
  * Form bean for the accesslog valve page.
  *
  * @author Manveen Kaur
- * @version $Revision: 302726 $ $Date: 2004-02-27 08:59:07 -0600 (Fri, 27 Feb 2004) $
+ * @version $Revision: 479010 $ $Date: 2006-11-24 14:46:09 -0700 (Fri, 24 Nov 2006) $
  */
 
 public final class AccessLogValveForm extends ValveForm {
@@ -308,34 +309,28 @@ public final class AccessLogValveForm extends ValveForm {
         
         ActionErrors errors = new ActionErrors();
         
-        String submit = request.getParameter("submit");
-        
-        // front end validation when save is clicked.        
-         //if (submit != null) {
+        // if not specified, default is access_log.
+        // to specify no prefix, specify a 0 length string...
+        if ((prefix == null) || (prefix.length() == 0)){
+            prefix = "access_log.";
+        }
             
-             // if not specified, default is access_log.
-             // to specify no prefix, specify a 0 length string...
-            if ((prefix == null) || (prefix.length() == 0)){
-                prefix = "access_log.";
-            }
-            
-            // default is a 0 length string
-            if ((suffix == null) || (suffix.length() < 1)) {
-                suffix = "";
-            }
+        // default is a 0 length string
+        if ((suffix == null) || (suffix.length() < 1)) {
+            suffix = "";
+        }
                                     
-            // If no directory attribute is specified, the default
-            // value is "logs".
-            if ((directory == null) || (directory.length() < 1)) {
-                directory = "logs";
-            }
+        // If no directory attribute is specified, the default
+        // value is "logs".
+        if ((directory == null) || (directory.length() < 1)) {
+            directory = "logs";
+        }
+
+        if ((pattern == null) || (pattern.length() < 1)) {
+            errors.add("pattern",
+            new ActionMessage("error.pattern.required"));
+        }         
 
-            if ((pattern == null) || (pattern.length() < 1)) {
-                errors.add("pattern",
-                new ActionError("error.pattern.required"));
-            }         
-        //}
-                 
         return errors;
     }
 }
