@@ -1,9 +1,10 @@
 /*
- * Copyright 1999,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -150,7 +151,7 @@ import org.apache.commons.modeler.Registry;
  *
  * @author Craig R. McClanahan
  * @author Remy Maucherat
- * @version $Revision: 393613 $ $Date: 2006-04-12 16:08:01 -0500 (Wed, 12 Apr 2006) $
+ * @version $Revision: 565467 $ $Date: 2007-08-13 12:25:14 -0600 (Mon, 13 Aug 2007) $
  */
 
 public class ManagerServlet
@@ -624,14 +625,12 @@ public class ManagerServlet
                 try {
                     // Upload WAR
                     uploadWar(request, localWar);
-                    // Copy WAR and XML to the host app base if needed
+                    // Copy WAR to the host app base if needed
                     if (tag != null) {
                         deployedPath = deployed;
                         File localWarCopy = new File(deployedPath, basename + ".war");
                         copy(localWar, localWarCopy);
-                        localWar = localWarCopy;
-                        copy(localWar, new File(getAppBase(), basename + ".war"));
-                    }
+                     }
                     // Perform new deployment
                     check(path);
                 } finally {
@@ -683,8 +682,6 @@ public class ManagerServlet
 
         // Find the local WAR file
         File localWar = new File(deployedPath, getDocBase(path) + ".war");
-        // Find the local context deployment file (if any)
-        File localXml = new File(configBase, getConfigFile(path) + ".xml");
 
         // Check if app already exists, or undeploy it if updating
         Context context = (Context) host.findChild(path);
@@ -798,6 +795,7 @@ public class ManagerServlet
                 addServiced(path);
                 try {
                     if (config != null) {
+                        configBase.mkdirs();
                         copy(new File(config), 
                                 new File(configBase, getConfigFile(path) + ".xml"));
                     }
@@ -1276,6 +1274,12 @@ public class ManagerServlet
                 }
             }
 
+            if (!isDeployed(path)) {
+                writer.println(sm.getString("managerServlet.notDeployed",
+                        RequestUtil.filter(displayPath)));
+                return;
+            }
+
             if (!isServiced(path)) {
                 addServiced(path);
                 try {
@@ -1367,6 +1371,19 @@ public class ManagerServlet
     }
 
 
+    /**
+     * Invoke the isDeployed method on the deployer.
+     */
+    protected boolean isDeployed(String name) 
+        throws Exception {
+        String[] params = { name };
+        String[] signature = { "java.lang.String" };
+        Boolean result = 
+            (Boolean) mBeanServer.invoke(oname, "isDeployed", params, signature);
+        return result.booleanValue();
+    }
+    
+
     /**
      * Invoke the check method on the deployer.
      */
@@ -1379,7 +1396,7 @@ public class ManagerServlet
     
 
     /**
-     * Invoke the check method on the deployer.
+     * Invoke the isServiced method on the deployer.
      */
     protected boolean isServiced(String name) 
         throws Exception {
@@ -1392,7 +1409,7 @@ public class ManagerServlet
     
 
     /**
-     * Invoke the check method on the deployer.
+     * Invoke the addServiced method on the deployer.
      */
     protected void addServiced(String name) 
         throws Exception {
@@ -1403,7 +1420,7 @@ public class ManagerServlet
     
 
     /**
-     * Invoke the check method on the deployer.
+     * Invoke the removeServiced method on the deployer.
      */
     protected void removeServiced(String name) 
         throws Exception {
