@@ -1,9 +1,10 @@
 /*
- * Copyright 1999,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -45,8 +46,6 @@ import javax.servlet.jsp.tagext.BodyContent;
 
 import org.apache.commons.el.ExpressionEvaluatorImpl;
 import org.apache.commons.el.VariableResolverImpl;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.apache.jasper.Constants;
 import org.apache.jasper.compiler.Localizer;
 import org.apache.jasper.security.SecurityUtil;
@@ -64,9 +63,6 @@ import org.apache.jasper.security.SecurityUtil;
  */
 public class PageContextImpl extends PageContext implements VariableResolver {
 
-    // Logger
-    private static Log log = LogFactory.getLog(PageContextImpl.class);
-
     // The expression evaluator, for evaluating EL expressions.
     private static ExpressionEvaluatorImpl elExprEval
         = new ExpressionEvaluatorImpl(false);
@@ -132,7 +128,8 @@ public class PageContextImpl extends PageContext implements VariableResolver {
         this.context = config.getServletContext();
         this.errorPageURL = errorPageURL;
         this.request = request;
-         this.response = response;
+        this.response = response;
+
 
         // Setup session (if required)
         if (request instanceof HttpServletRequest && needsSession)
@@ -182,7 +179,8 @@ public class PageContextImpl extends PageContext implements VariableResolver {
                 ((JspWriterImpl)out).flushBuffer();
             }
         } catch (IOException ex) {
-            log.warn("Internal error flushing the buffer in release()");
+            context.log(
+                "PageContextImpl.release(): Internal error flushing buffer");
         }
 
         servlet = null;
@@ -851,8 +849,17 @@ public class PageContextImpl extends PageContext implements VariableResolver {
         return variableResolver.resolveVariable(pName);
     }
 
+    /**
+     * XML-escape the given string.
+     *
+     * @param s The string to escape
+     * @return The escape string
+     */
     private static String XmlEscape(String s) {
-        if (s == null) return null;
+        if (s == null) {
+            return null;
+        }
+
         StringBuffer sb = new StringBuffer();
         for(int i = 0; i < s.length(); i++) {
             char c = s.charAt(i);
